@@ -52,6 +52,8 @@ GAMGI_CHEM_FM, GAMGI_CHEM_MD, GAMGI_CHEM_NO, GAMGI_CHEM_LR, GAMGI_CHEM_RF,
 GAMGI_CHEM_DB, GAMGI_CHEM_SG, GAMGI_CHEM_BH, GAMGI_CHEM_HS, GAMGI_CHEM_MT, 
 GAMGI_CHEM_DS, GAMGI_CHEM_RG };
 
+enum { GAMGI_CHEM_CONTAINER = 1, GAMGI_CHEM_POLYTOPE };
+
 /*******************************************
  *         number of atomic elements       *
  *                                         *
@@ -65,12 +67,12 @@ GAMGI_CHEM_DS, GAMGI_CHEM_RG };
 
 #define GAMGI_CHEM_ATOM_MAX 111
 
-/****************************************
- * maximum number of char in atom type, *
- * including the final '\0' char.       *
- ****************************************/
+/**********************************************************************
+ * maximum number of char in atom label, without the final '\0': it   *
+ * should be smaller than GAMGI_ENGINE_TOKEN, where labels are stored *
+ **********************************************************************/
 
-#define GAMGI_CHEM_ATOM_TYPE 10
+#define GAMGI_CHEM_ATOM_LABEL 10
 
 /***********************
  * Default atom charge *
@@ -220,4 +222,28 @@ GAMGI_CHEM_DS, GAMGI_CHEM_RG };
 #define GAMGI_CHEM_IONIC_HS -30
 #define GAMGI_CHEM_IONIC_COORDINATION 1000
 
+/***********************************************
+ * tolerances used in polytope code:           *
+ * width: minimum width for cells box          *
+ *                                             *
+ * length: minimum length to build directions  *
+ * area: minimum area to build planes          *
+ * volume: minimum volume to build polyhedrons *
+ *                                             *
+ * visible: minimum value for visible faces    *
+ * coplanar: maximum range for coplanar faces  *
+ ***********************************************/
+
+#define GAMGI_CHEM_POLYTOPE_TOLERANCE_WIDTH  1.0E-1
+
+#define GAMGI_CHEM_POLYTOPE_TOLERANCE_LENGTH 1.0E-2
+#define GAMGI_CHEM_POLYTOPE_TOLERANCE_AREA   1.0E-2
+#define GAMGI_CHEM_POLYTOPE_TOLERANCE_VOLUME 1.0E-2
+
+#define GAMGI_CHEM_POLYTOPE_TOLERANCE_VISIBLE  1.0E-10
+#define GAMGI_CHEM_POLYTOPE_TOLERANCE_COPLANAR 1.0E-02
+
+#define GAMGI_CHEM_POLYTOPE_TOLERANCE_VISIBLE_MAX  1.0E-05
+#define GAMGI_CHEM_POLYTOPE_TOLERANCE_COPLANAR_MAX 1.0E-01
+
 #endif
