@@ -16,12 +16,20 @@
 #include "gamgi_engine_link.h"
 #include "gamgi_engine_number.h"
 
+static void static_start (gamgi_object *object)
+{
+object->selection = NULL;
+object->object = NULL;
+object->dlist = NULL;
+}
+
 gamgi_text *gamgi_engine_copy_text (gamgi_text *text)
 {
 gamgi_dlist *dlist;
 gamgi_text *text_new, *text_child;
 
 text_new = gamgi_engine_create_text ();
+static_start (GAMGI_CAST_OBJECT text_new);
 gamgi_engine_copy_out_text (text, text_new);
 text_new->object.number = gamgi_engine_number_text_get ();
 
@@ -41,6 +49,7 @@ gamgi_text *text_new;
 gamgi_orbital *orbital_new;
 
 orbital_new = gamgi_engine_create_orbital ();
+static_start (GAMGI_CAST_OBJECT orbital_new);
 gamgi_engine_copy_out_orbital (orbital, orbital_new);
 orbital_new->object.number = gamgi_engine_number_orbital_get ();
 
@@ -61,6 +70,7 @@ gamgi_orbital *orbital_new;
 gamgi_bond *bond_new;
 
 bond_new = gamgi_engine_create_bond ();
+static_start (GAMGI_CAST_OBJECT bond_new);
 gamgi_engine_copy_out_bond (bond, bond_new);
 bond_new->object.number = gamgi_engine_number_bond_get ();
 
@@ -88,6 +98,7 @@ gamgi_bond *bond, *bond_new;
 gamgi_atom *atom_new;
 
 atom_new = gamgi_engine_create_atom ();
+static_start (GAMGI_CAST_OBJECT atom_new);
 gamgi_engine_copy_out_atom (atom, atom_new);
 atom_new->object.number = gamgi_engine_number_atom_get ();
 
@@ -138,6 +149,7 @@ gamgi_atom *atom_new;
 gamgi_direction *direction_new;
 
 direction_new = gamgi_engine_create_direction ();
+static_start (GAMGI_CAST_OBJECT direction_new);
 gamgi_engine_copy_out_direction (direction, direction_new);
 direction_new->object.number = gamgi_engine_number_direction_get ();
 
@@ -171,6 +183,7 @@ gamgi_atom *atom_new;
 gamgi_plane *plane_new;
 
 plane_new = gamgi_engine_create_plane ();
+static_start (GAMGI_CAST_OBJECT plane_new);
 gamgi_engine_copy_out_plane (plane, plane_new);
 plane_new->object.number = gamgi_engine_number_plane_get ();
 
@@ -206,6 +219,7 @@ gamgi_plane *plane_new;
 gamgi_group *group_new, *group_child;
 
 group_new = gamgi_engine_create_group (); 
+static_start (GAMGI_CAST_OBJECT group_new);
 gamgi_engine_copy_out_group (group, group_new);
 group_new->object.number = gamgi_engine_number_group_get ();
 
@@ -260,6 +274,7 @@ gamgi_group *group_new;
 gamgi_molecule *molecule_new;
 
 molecule_new = gamgi_engine_create_molecule (); 
+static_start (GAMGI_CAST_OBJECT molecule_new);
 gamgi_engine_copy_out_molecule (molecule, molecule_new);
 molecule_new->object.number = gamgi_engine_number_molecule_get ();
 
@@ -315,6 +330,7 @@ gamgi_molecule *molecule_new;
 gamgi_cluster *cluster_new, *cluster_child;
 
 cluster_new = gamgi_engine_create_cluster (); 
+static_start (GAMGI_CAST_OBJECT cluster_new);
 gamgi_engine_copy_out_cluster (cluster, cluster_new);
 cluster_new->object.number = gamgi_engine_number_cluster_get ();
 
@@ -383,6 +399,7 @@ gamgi_cluster *cluster_new;
 gamgi_cell *cell_new;
 
 cell_new = gamgi_engine_create_cell (); 
+static_start (GAMGI_CAST_OBJECT cell_new);
 gamgi_engine_copy_out_cell (cell, cell_new);
 cell_new->object.number = gamgi_engine_number_cell_get ();
 
@@ -444,6 +461,7 @@ gamgi_text *text_new;
 gamgi_arrow *arrow_new;
 
 arrow_new = gamgi_engine_create_arrow ();
+static_start (GAMGI_CAST_OBJECT arrow_new);
 gamgi_engine_copy_out_arrow (arrow, arrow_new);
 arrow_new->object.number = gamgi_engine_number_arrow_get ();
 
@@ -463,6 +481,7 @@ gamgi_text *text_new;
 gamgi_shape *shape_new;
 
 shape_new = gamgi_engine_create_shape ();
+static_start (GAMGI_CAST_OBJECT shape_new);
 gamgi_engine_copy_out_shape (shape, shape_new);
 shape_new->object.number = gamgi_engine_number_shape_get ();
 
@@ -482,6 +501,7 @@ gamgi_text *text_new;
 gamgi_graph *graph_new;
 
 graph_new = gamgi_engine_create_graph ();
+static_start (GAMGI_CAST_OBJECT graph_new);
 gamgi_engine_copy_out_graph (graph, graph_new);
 graph_new->object.number = gamgi_engine_number_graph_get ();
 
@@ -512,6 +532,7 @@ gamgi_graph *graph_new;
 gamgi_assembly *assembly_new, *assembly_child;
 
 assembly_new = gamgi_engine_create_assembly ();
+static_start (GAMGI_CAST_OBJECT assembly_new);
 gamgi_engine_copy_out_assembly (assembly, assembly_new);
 assembly_new->object.number = gamgi_engine_number_assembly_get ();
 
@@ -601,6 +622,7 @@ gamgi_light *gamgi_engine_copy_light (gamgi_light *light)
 gamgi_light *light_new;
 
 light_new = gamgi_engine_create_light ();
+static_start (GAMGI_CAST_OBJECT light_new);
 gamgi_engine_copy_out_light (light, light_new);
 light_new->object.number = gamgi_engine_number_light_get ();
 
@@ -627,6 +649,7 @@ gamgi_light *light_new;
 gamgi_layer *layer_new;
 
 layer_new = gamgi_engine_create_layer ();
+static_start (GAMGI_CAST_OBJECT layer_new);
 gamgi_engine_copy_out_layer (layer, layer_new);
 layer_new->object.number = gamgi_engine_number_layer_get ();
 
@@ -725,6 +748,7 @@ gamgi_layer *layer_new;
 gamgi_window *window_new;
 
 window_new = gamgi_engine_create_window ();
+static_start (GAMGI_CAST_OBJECT window_new);
 gamgi_engine_copy_out_window (window, window_new);
 window_new->object.number = gamgi_engine_number_window_get ();
 
