@@ -20,11 +20,9 @@
 static void static_copy (gamgi_object *object, gamgi_object *object_new)
 {
 strcpy (object_new->name, object->name);
-strcpy (object_new->type, object->type);
+strcpy (object_new->label, object->label);
 object_new->class = object->class;
 object_new->scale = object->scale;
-object_new->object = NULL;
-object_new->dlist = NULL;
 }
 
 void gamgi_engine_copy_out_text (gamgi_text *text, gamgi_text *text_new)
@@ -144,7 +142,9 @@ gamgi_direction *direction_new)
 int i;
 
 static_copy (GAMGI_CAST_OBJECT direction, GAMGI_CAST_OBJECT direction_new);
+direction_new->projection = direction->projection;
 direction_new->draw = direction->draw;
+direction_new->type = direction->type;
 
 /*****************************
  * copy description: indices *
@@ -184,13 +184,6 @@ direction_new->quaternion[1] = direction->quaternion[1];
 direction_new->quaternion[2] = direction->quaternion[2];
 direction_new->quaternion[3] = direction->quaternion[3];
 
-/*************************************************
- * copy visualization: draw,projection functions *
- *************************************************/
-
-direction_new->projection = direction->projection;
-direction_new->draw = direction->draw;
-
 /******************************
  * copy arrays: points, loops *
  ******************************/
@@ -212,11 +205,9 @@ while (i-- > 0)
 direction_new->n_points = direction->n_points;
 direction_new->n_loops = direction->n_loops;
 
-/*********************************************
- * copy visualization: representation, color *
- *********************************************/
-
-direction_new->type = direction->type;
+/*****************************
+ * copy visualization: color *
+ *****************************/
 
 direction_new->red = direction->red;
 direction_new->green = direction->green;
@@ -228,6 +219,9 @@ void gamgi_engine_copy_out_plane (gamgi_plane *plane, gamgi_plane *plane_new)
 int i;
 
 static_copy (GAMGI_CAST_OBJECT plane, GAMGI_CAST_OBJECT plane_new);
+plane_new->projection = plane->projection;
+plane_new->draw = plane->draw;
+plane_new->type = plane->type;
 
 /*****************************
  * copy description: indices *
@@ -266,13 +260,6 @@ plane_new->quaternion[1] = plane->quaternion[1];
 plane_new->quaternion[2] = plane->quaternion[2];
 plane_new->quaternion[3] = plane->quaternion[3];
 
-/*************************************************
- * copy visualization: draw,projection functions *
- *************************************************/
-
-plane_new->projection = plane->projection;
-plane_new->draw = plane->draw;
-
 /********************************************
  * copy visualization arrays: points, loops *
  ********************************************/
@@ -294,11 +281,9 @@ while (i-- > 0)
 plane_new->n_points = plane->n_points;
 plane_new->n_loops = plane->n_loops;
 
-/*********************************************
- * copy visualization: representation, color *
- *********************************************/
-
-plane_new->type = plane->type;
+/**************
+ * copy color *
+ **************/
 
 plane_new->red = plane->red;
 plane_new->green = plane->green;
@@ -311,6 +296,16 @@ int i;
 
 static_copy (GAMGI_CAST_OBJECT group, GAMGI_CAST_OBJECT group_new);
 group_new->draw = group->draw;
+group_new->type = group->type;
+
+group_new->atom = group->atom;
+group_new->element = group->element;
+group_new->number = group->number;
+
+group_new->visible = group->visible;
+group_new->coplanar = group->coplanar;
+
+group_new->autonomy = group->autonomy;
 
 /**************************************
  * copy position and orientation data *
@@ -329,9 +324,9 @@ group_new->quaternion[1] = group->quaternion[1];
 group_new->quaternion[2] = group->quaternion[2];
 group_new->quaternion[3] = group->quaternion[3];
 
-/**************************************
- * copy arrays: points, loops, colors *
- **************************************/
+/******************************
+ * copy arrays: points, loops *
+ ******************************/
 
 group_new->points = NULL;
 i = 3 * group->n_points;
@@ -343,23 +338,19 @@ i = group->n_loops;
 if (i > 0) group_new->loops = (int *) malloc (sizeof (int) * i);
 while (i-- > 0) group_new->loops[i] = group->loops[i];
 
-/****************************************
- * copy number of points, loops, colors *
- ****************************************/
+/********************************
+ * copy number of points, loops *
+ ********************************/
 
 group_new->n_points = group->n_points;
 group_new->n_loops = group->n_loops;
 
-/************************
- * copy hide/show flags *
- ************************/
+/*********************
+ * copy faces, color *
+ *********************/
 
 group_new->faces = group->faces;
 
-/**************************
- * copy color information *
- **************************/
-
 group_new->red = group->red;
 group_new->green = group->green;
 group_new->blue = group->blue;
@@ -443,14 +434,14 @@ cluster_new->n_points = cluster->n_points;
 cluster_new->n_loops = cluster->n_loops;
 cluster_new->n_colors = cluster->n_colors;
 cluster_new->n_paints = cluster->n_paints;
-cluster_new->n_seeds = cluster->n_seeds;
+cluster_new->n_dots = cluster->n_dots;
 
 /************************
  * copy hide/show flags *
  ************************/
 
 cluster_new->faces = cluster->faces;
-cluster_new->seeds = cluster->seeds;
+cluster_new->dots = cluster->dots;
 }
 
 void gamgi_engine_copy_out_cell (gamgi_cell *cell, gamgi_cell *cell_new)
@@ -721,15 +712,15 @@ window_new->dialog0 = NULL;
 window_new->dialog1 = NULL;
 window_new->help = NULL;
 
+window_new->area = NULL;
+window_new->history = NULL;
 window_new->layer = NULL;
 window_new->focus = NULL;
 
-window_new->history = NULL;
 window_new->action = FALSE;
+window_new->mode = FALSE;
 window_new->axes = FALSE;
-window_new->selection = FALSE;
-
-window_new->area = NULL;
+window_new->class = FALSE;
 
 window_new->top_flag = TRUE;
 window_new->medium_flag = TRUE;
