@@ -10,6 +10,7 @@
  */
 
 #include "gamgi_engine.h"
+#include "gamgi_io.h"
 #include "gamgi_global.h"
 
 #include "gamgi_engine_number.h"
@@ -856,6 +857,33 @@ gamgi->layer = gamgi_global_create_layer ();
 gamgi->window = gamgi_global_create_window ();
 gamgi->gamgi = gamgi_global_create_gamgi ();
 
+/***********************************************
+ * initialize object selection lists, pointers *
+ ***********************************************/
+
+gamgi->texts = NULL;
+gamgi->orbitals = NULL;
+gamgi->bonds = NULL;
+gamgi->atoms = NULL;
+gamgi->directions = NULL;
+gamgi->planes = NULL;
+gamgi->groups = NULL;
+gamgi->molecules = NULL;
+gamgi->clusters = NULL;
+gamgi->cells = NULL;
+gamgi->arrows = NULL;
+gamgi->shapes = NULL;
+gamgi->graphs = NULL;
+gamgi->assemblys = NULL;
+gamgi->lights = NULL;
+gamgi->layers = NULL;
+gamgi->windows = NULL;
+
+gamgi->function = NULL;
+gamgi->window_dialog = NULL;
+gamgi->window_mouse = NULL;
+gamgi->state = FALSE;
+
 /**********************************
  * initialise pointers to objects *
  **********************************/
