@@ -41,6 +41,10 @@ int (* function) (const void *, const void *));
 gamgi_dlist *gamgi_engine_dlist_msort (gamgi_dlist *dlist_c,
 int (* function) (const void *, const void *));
 
+gamgi_slist *gamgi_engine_slist_invert (gamgi_slist *start);
+
+gamgi_dlist *gamgi_engine_dlist_invert (gamgi_dlist *start);
+
 /*************
  * Rationale *
  *************
