@@ -28,7 +28,7 @@
 #include "gamgi_global_copy.h"
 #include "gamgi_global_remove.h"
 
-static void static_name (GtkWidget *widget, void *data);
+static void static_element (GtkWidget *widget, void *data);
 static void static_number (GtkWidget *widget, void *data);
 
 /************************ internal function *************************
@@ -111,7 +111,7 @@ else
 
 }
 
-static void static_name (GtkWidget *widget, void *data)
+static void static_element (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -128,8 +128,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
  * should not be used to change name entry again! *
  **************************************************/
 
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry),
-GTK_SIGNAL_FUNC (static_number), window);
+g_signal_handlers_block_by_func (entry, static_number, window);
 
 /************************************
  * get name, get number, set number *
@@ -155,8 +154,7 @@ else
  * accepts changes done directly in that entry    *
  **************************************************/
 
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry),
-G_CALLBACK (static_number), window);
+g_signal_handlers_unblock_by_func (entry, static_number, window);
 }
 
 static void static_number (GtkWidget *widget, void *data)
@@ -168,7 +166,7 @@ const char *name;
 char token[GAMGI_ENGINE_TOKEN];
 int number;
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_name");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_element");
 
 /********************************************
  * block changed signal for name entry so   *
@@ -176,8 +174,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_name");
  * be used to change number entry again!    *
  ********************************************/
 
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry),
-GTK_SIGNAL_FUNC (static_name), window);
+g_signal_handlers_block_by_func (entry, static_element, window);
 
 /**********************************
  * get number, get name, set name *
@@ -202,8 +199,7 @@ else
  * accepts changes done directly in that entry  *
  ************************************************/
 
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry),
-G_CALLBACK (static_name), window);
+g_signal_handlers_unblock_by_func (entry, static_element, window);
 }
 
 static void static_button (GtkWidget *dialog, char *string)
@@ -367,7 +363,8 @@ if (row == GAMGI_MESA_WIRED - 1) atom_class->draw = gamgi_mesa_atom_draw_cross;
 if (row == GAMGI_MESA_SOLID - 1) atom_class->draw = gamgi_mesa_atom_draw_sphere;
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
-name = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child));
+entry = gtk_bin_get_child (GTK_BIN (combo));
+name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_float_scan (name, &atom_class->size,
 GAMGI_MATH_TOLERANCE, FLT_MAX) == FALSE)
   {
@@ -376,9 +373,11 @@ GAMGI_MATH_TOLERANCE, FLT_MAX) == FALSE)
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_variancy");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_variancy");
+entry = gtk_bin_get_child (GTK_BIN (combo));
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_float_scan (name, &atom_class->variancy, 0.0, 1.0) == FALSE)
+if (gamgi_io_token_float_scan (name, &atom_class->variancy,
+0.0, FLT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid variancy", window);
   gamgi_global_remove_atom (atom_class);
@@ -575,10 +574,12 @@ if (atom_class->draw == gamgi_mesa_atom_draw_sphere)
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SIZE, atom_class->size);
-gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), token);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_text (GTK_ENTRY (entry), token);
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_variancy");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_variancy");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_VARIANCY, atom_class->variancy);
+entry = gtk_bin_get_child (GTK_BIN (combo));
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
 /********************************************
@@ -606,10 +607,9 @@ GtkWidget *notebook;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top;
 GtkWidget *combo;
 GtkListStore *store;
 GtkCellRenderer *renderer;
@@ -639,37 +639,35 @@ gtk_widget_show (vbox_dialog);
 notebook = gtk_notebook_new ();
 gtk_box_pack_start (GTK_BOX (vbox_dialog), notebook, FALSE, FALSE, 0);
 gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
-g_signal_connect (GTK_OBJECT (notebook), "switch_page",
+g_signal_connect (notebook, "switch_page",
 G_CALLBACK (static_switch), window);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
-/****************
- * Element page *
- ****************/
+/*************
+ * Type page *
+ *************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new ("Element");
+label = gtk_label_new (" Type ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_top = gtk_vbox_new (FALSE, 10);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
 
-/***********************
- * name, number, table *
- ***********************/
+/**************************
+ * element, number, table *
+ **************************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 15);
@@ -680,7 +678,7 @@ hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left_left);
 
-label = gtk_label_new ("Name");
+label = gtk_label_new ("Element");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
@@ -688,9 +686,9 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
-g_signal_connect (GTK_OBJECT (entry), "changed",
-G_CALLBACK (static_name), window);
-g_object_set_data (G_OBJECT (dialog), "entry_name", entry);
+g_signal_connect (entry, "changed",
+G_CALLBACK (static_element), window);
+g_object_set_data (G_OBJECT (dialog), "entry_element", entry);
 gtk_widget_show (entry);
 
 hbox_left_left = gtk_hbox_new (FALSE, 5);
@@ -705,14 +703,14 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_number), window);
 g_object_set_data (G_OBJECT (dialog), "entry_number", entry);
 gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Table");
 gtk_box_pack_end (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_table), window);
 g_object_set_data (G_OBJECT (dialog), "button_table", button);
 gtk_widget_show (button);
@@ -722,10 +720,10 @@ gtk_widget_show (button);
  ****************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 15);
+hbox_left = gtk_hbox_new (FALSE, 20);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
@@ -746,7 +744,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("List");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_atom_property_mass), window);
 g_object_set_data (G_OBJECT (dialog), "button_mass", button);
 gtk_widget_show (button);
@@ -768,7 +766,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("List");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_atom_property_radius), window);
 g_object_set_data (G_OBJECT (dialog), "button_radius", button);
 gtk_widget_show (button);
@@ -780,25 +778,19 @@ gtk_widget_show (button);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Analysis");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /***************
  * temperature *
  ***************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
@@ -823,31 +815,33 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
-vbox_frame = gtk_vbox_new (TRUE, 5);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_top = gtk_vbox_new (FALSE, 10);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
 
-/***********************
- * style,size,variancy *
- ***********************/
+/********************
+ * style, size, min *
+ ********************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 10);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
+/*********
+ * style *
+ *********/
+
 hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left_left);
@@ -873,6 +867,10 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
+/********
+ * size *
+ ********/
+
 hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left_left);
@@ -884,8 +882,9 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_entry_new ();
 gtk_box_pack_end (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "combo_size", combo);
 gtk_widget_show (combo);
 
@@ -904,34 +903,6 @@ g_object_unref (store);
 
 gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
 
-hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left_left);
-
-label = gtk_label_new ("Variancy");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_variancy", label);
-gtk_widget_show (label);
-
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_object_set_data (G_OBJECT (dialog), "entry_variancy", entry);
-gtk_widget_show (entry);
-
-/******************
- * minimum radius *
- ******************/
-
-hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
-gtk_widget_show (hbox_center);
-
-hbox_left = gtk_hbox_new (FALSE, 15);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
-
 /***********************************
  *  minimum radius (H, by default) *
  ***********************************/
@@ -951,6 +922,51 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_min", entry);
 gtk_widget_show (entry);
 
+/***************************
+ * variancy, slices, width *
+ ***************************/
+
+hbox_center = gtk_hbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+hbox_left = gtk_hbox_new (FALSE, 15);
+gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
+
+/************
+ * variancy *
+ ************/
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+label = gtk_label_new ("Variancy");
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_variancy", label);
+gtk_widget_show (label);
+
+combo = gtk_combo_box_entry_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_object_set_data (G_OBJECT (dialog), "combo_variancy", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.0);
+gtk_list_store_set (store, &iter, 0, token, -1);
+gtk_list_store_append (store, &iter);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 1.0);
+gtk_list_store_set (store, &iter, 0, token, -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
+
 /******************************
  * spherical/cylindric Slices *
  ******************************/
@@ -994,7 +1010,7 @@ gtk_widget_show (entry);
  *********/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (1, 7, FALSE);
@@ -1049,17 +1065,15 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
