@@ -447,7 +447,7 @@ gamgi_bool *sensitive;
 
 dialog = gamgi_gtk_dialog_task1_create ("Align Translation", window);
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-g_signal_connect (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect (dialog, "delete_event",
 G_CALLBACK (static_translation_delete), window);
 
 vbox_dialog = gtk_vbox_new (FALSE, 5);
@@ -580,14 +580,14 @@ gtk_widget_show (hbox_left);
 
 button = gtk_radio_button_new_with_label (NULL, "Layer");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_translation_clicked), window);
 gtk_widget_show (button);
 
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Cell");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_translation_clicked), window);
 g_object_set_data (G_OBJECT (dialog), "button_cell", button);
 gtk_widget_show (button);
@@ -696,18 +696,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_translation_ok), window);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_translation_cancel), window);
 gtk_widget_show (button);
 
@@ -945,10 +943,7 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_uvw");
  * not be used to change hkl combo box again *
  *********************************************/
 
-gtk_signal_handler_block_by_func (GTK_OBJECT (combo),
-G_CALLBACK (static_rotation_uvw), window);
-gtk_signal_handler_block_by_func (GTK_OBJECT (combo),
-G_CALLBACK (static_rotation_uvw), window);
+g_signal_handlers_block_by_func (combo, static_rotation_uvw, window);
 
 if (row == 0)
   gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 1);
@@ -960,10 +955,7 @@ else
  * handles changes done directly to uvw combo box  *
  ***************************************************/
 
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (combo),
-G_CALLBACK (static_rotation_uvw), window);
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (combo),
-G_CALLBACK (static_rotation_uvw), window);
+g_signal_handlers_unblock_by_func (combo, static_rotation_uvw, window);
 
 static_rotation_label (window);
 }
@@ -996,10 +988,7 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_hkl");
  * not be used to change uvw combo box again *
  *********************************************/
 
-gtk_signal_handler_block_by_func (GTK_OBJECT (combo),
-G_CALLBACK (static_rotation_hkl), window);
-gtk_signal_handler_block_by_func (GTK_OBJECT (combo),
-G_CALLBACK (static_rotation_hkl), window);
+g_signal_handlers_block_by_func (combo, static_rotation_hkl, window);
 
 if (row == 0)
   gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 1);
@@ -1011,10 +1000,7 @@ else
  * handles changes done directly to hkl combo box  *
  ***************************************************/
 
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (combo),
-G_CALLBACK (static_rotation_hkl), window);
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (combo),
-G_CALLBACK (static_rotation_hkl), window);
+g_signal_handlers_unblock_by_func (combo, static_rotation_hkl, window);
 
 static_rotation_label (window);
 }
@@ -1166,8 +1152,7 @@ gamgi_cell *cell;
 GtkWidget *dialog = window->dialog1;
 GtkWidget *entry;
 GtkWidget *button;
-GtkWidget *option_menu, *menu;
-GtkWidget *item, *item_now;
+GtkWidget *combo;
 const char *name;
 
 /************************
@@ -1193,7 +1178,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
  * get Cell plane indices *
  **************************/
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_h");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell_h");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.cell_hkl[0], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1201,7 +1186,7 @@ if (gamgi_io_token_int_scan (name, &rotation.cell_hkl[0], -INT_MAX, INT_MAX) ==
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_k");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell_k");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.cell_hkl[1], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1209,7 +1194,7 @@ if (gamgi_io_token_int_scan (name, &rotation.cell_hkl[1], -INT_MAX, INT_MAX) ==
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_l");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell_l");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.cell_hkl[2], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1227,7 +1212,7 @@ if (gamgi_phys_direction_zero (rotation.cell_hkl) == TRUE)
  * get Cell direction indices *
  ******************************/
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_u");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell_u");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.cell_uvw[0], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1235,7 +1220,7 @@ if (gamgi_io_token_int_scan (name, &rotation.cell_uvw[0], -INT_MAX, INT_MAX) ==
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell_v");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.cell_uvw[1], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1243,7 +1228,7 @@ if (gamgi_io_token_int_scan (name, &rotation.cell_uvw[1], -INT_MAX, INT_MAX) ==
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cell_w");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.cell_uvw[2], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1261,13 +1246,8 @@ if (gamgi_phys_direction_zero (rotation.cell_uvw) == TRUE)
  * get Cell vectors *
  ********************/
 
-option_menu = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "menu_cell");
-menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-item_now = gtk_menu_get_active (GTK_MENU (menu));
-
-rotation.cell_vectors = GAMGI_PHYS_CONVENTIONAL;
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_cell");
-if (item == item_now) rotation.cell_vectors = GAMGI_PHYS_PRIMITIVE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_cell");
+rotation.cell_vectors = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /************************************
  * get Reference vector (given by   *
@@ -1275,7 +1255,7 @@ if (item == item_now) rotation.cell_vectors = GAMGI_PHYS_PRIMITIVE;
  * Cell vector (given by Plane)     *
  ************************************/
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_h1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_h");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.base_hkl[0], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1283,7 +1263,7 @@ if (gamgi_io_token_int_scan (name, &rotation.base_hkl[0], -INT_MAX, INT_MAX) ==
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_k1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_k");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.base_hkl[1], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1291,7 +1271,7 @@ if (gamgi_io_token_int_scan (name, &rotation.base_hkl[1], -INT_MAX, INT_MAX) ==
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_l1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_l");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.base_hkl[2], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1311,7 +1291,7 @@ if (gamgi_phys_direction_zero (rotation.base_hkl) == TRUE)
  * Cell vector (given by Direction) *
  ************************************/
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_u1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_u");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.base_uvw[0], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1319,7 +1299,7 @@ if (gamgi_io_token_int_scan (name, &rotation.base_uvw[0], -INT_MAX, INT_MAX) ==
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_v");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.base_uvw[1], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1327,7 +1307,7 @@ if (gamgi_io_token_int_scan (name, &rotation.base_uvw[1], -INT_MAX, INT_MAX) ==
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_w");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &rotation.base_uvw[2], -INT_MAX, INT_MAX) == FALSE)
   {
@@ -1368,13 +1348,8 @@ if (gamgi_phys_direction_weiss (rotation.base_hkl, rotation.base_uvw) == FALSE)
  * get base vectors *
  ********************/
 
-option_menu = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "menu_base");
-menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-item_now = gtk_menu_get_active (GTK_MENU (menu));
-
-rotation.base_vectors = GAMGI_PHYS_CONVENTIONAL;
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_base");
-if (item == item_now) rotation.base_vectors = GAMGI_PHYS_PRIMITIVE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_base");
+rotation.base_vectors = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /**********************************************
  * get information on which indices represent *
@@ -1384,13 +1359,8 @@ if (item == item_now) rotation.base_vectors = GAMGI_PHYS_PRIMITIVE;
 rotation.plane = -1;
 if (rotation.base->class == GAMGI_ENGINE_CELL)
   {
-  option_menu = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "menu_hkl");
-  menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-  item_now = gtk_menu_get_active (GTK_MENU (menu));
-
-  item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_hkl");
-  if (item == item_now) rotation.plane = 0;
-  else rotation.plane = 1;
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_base");
+  rotation.plane = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
   }
 
 static_rotation_disable (window);
@@ -1521,7 +1491,7 @@ gamgi_bool *sensitive;
 
 dialog = gamgi_gtk_dialog_task1_create ("Align Rotation", window);
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-g_signal_connect (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect (dialog, "delete_event",
 G_CALLBACK (static_rotation_delete), window);
 
 vbox_dialog = gtk_vbox_new (FALSE, 5);
@@ -1695,14 +1665,14 @@ gtk_widget_show (hbox_left);
 
 button = gtk_radio_button_new_with_label (NULL, "Layer");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_rotation_clicked), window);
 gtk_widget_show (button);
 
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Cell");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_rotation_clicked), window);
 g_object_set_data (G_OBJECT (dialog), "button_cell", button);
 gtk_widget_show (button);
@@ -1728,7 +1698,7 @@ gtk_widget_show (table);
 
 combo = gtk_combo_box_new ();
 gtk_table_attach (GTK_TABLE (table), combo, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_rotation_hkl), window);
 g_object_set_data (G_OBJECT (dialog), "combo_hkl", combo);
 gtk_widget_show (combo);
@@ -1792,7 +1762,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_table_attach (GTK_TABLE (table), combo, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 5, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_rotation_uvw), window);
 g_object_set_data (G_OBJECT (dialog), "combo_uvw", combo);
 gtk_widget_show (combo);
@@ -1899,17 +1869,15 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_rotation_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_rotation_cancel), window);
 gtk_widget_show (button);
 
@@ -1980,15 +1948,12 @@ x = translation.cell_xyz[0];
 y = translation.cell_xyz[1];
 z = translation.cell_xyz[2];
 
-gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
-gamgi_math_cell_offset (cell, offset);
-
 if (translation.cell_vectors == GAMGI_PHYS_CONVENTIONAL)
   gamgi_math_vector_translation (x, y, z, cell->a1, cell->a2, cell->a3, position);
 if (translation.cell_vectors == GAMGI_PHYS_PRIMITIVE)
   gamgi_math_vector_translation (x, y, z, cell->p1, cell->p2, cell->p3, position);
 
-gamgi_math_vector_add (offset, position, position);
+gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
 gamgi_math_matrix_vector (rotate, position, c);
 
 /************************
@@ -2002,32 +1967,27 @@ z = translation.base_xyz[2];
 if (translation.base->class == GAMGI_ENGINE_CELL)
   {
   base = GAMGI_CAST_CELL translation.base;
-  gamgi_math_quaternion_to_matrix (base->quaternion, rotate);
-  gamgi_math_vector_copy (base->origin, origin);
-  gamgi_math_cell_offset (base, offset);
 
   if (translation.base_vectors == GAMGI_PHYS_CONVENTIONAL)
     gamgi_math_vector_translation (x, y, z, base->a1, base->a2, base->a3, position);
   if (translation.base_vectors == GAMGI_PHYS_PRIMITIVE)
     gamgi_math_vector_translation (x, y, z, base->p1, base->p2, base->p3, position);
-  }
-else
-  {
-  gamgi_math_matrix_unit (rotate);
-  gamgi_math_vector_zero (origin);
-  gamgi_math_vector_zero (offset);
-  gamgi_math_vector_absolute (position, x, y, z);
-  }
 
-gamgi_math_vector_add (offset, position, position);
-gamgi_math_matrix_vector (rotate, position, b);
+  gamgi_math_cell_offset (base, offset);
+  gamgi_math_vector_add (offset, position, position);
+
+  gamgi_math_quaternion_to_matrix (base->quaternion, rotate);
+  gamgi_math_matrix_vector (rotate, position, b);
+
+  gamgi_math_vector_add (base->origin, b, b);
+  }
+else gamgi_math_vector_absolute (b, x, y, z); 
 
 /*******************************
  * get cell origin such that   *
  * points b and c are the same *
  *******************************/
 
-gamgi_math_vector_add (origin, b, b);
 gamgi_math_vector_sub (b, c, origin);
 }
 
@@ -2072,6 +2032,9 @@ gamgi_math_matrix_inverse (matrix, inverse);
 
 if (rotation.plane == -1)
   {
+  /****************************************
+   * rotated, translated layers work fine *
+   ****************************************/
   gamgi_math_vector_absolute (a, 
   rotation.base_hkl[0], rotation.base_hkl[1], rotation.base_hkl[2]);
   gamgi_math_vector_absolute (b, 
