@@ -40,6 +40,13 @@ GtkWidget *combo;
 gamgi_enum lattice, vectors;
 int row;
 
+/***************************************************
+ * this is not necessary but prevents a O3 warning *
+ ***************************************************/
+
+vectors = FALSE;
+lattice = FALSE;
+
 /************************************************************
  *                          update o4                       *
  *                                                          *
@@ -56,7 +63,7 @@ if (row == GAMGI_PHYS_CONVENTIONAL - 1)
   lattice = gamgi_gtk_cell_symmetry_lattice (dialog);
   }
 
-else if (row == GAMGI_PHYS_PRIMITIVE - 1)
+if (row == GAMGI_PHYS_PRIMITIVE - 1)
   {
   vectors = GAMGI_PHYS_PRIMITIVE;
   lattice = GAMGI_PHYS_CUBIC_P;
@@ -71,29 +78,29 @@ static void static_faces (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *option_menu, *menu;
-GtkWidget *item, *item_now;
+GtkWidget *combo;
+gamgi_bool *sensitive;
+int row;
 
-/*************************************
- * get borders option menu addresses *
- *************************************/
+/*************************
+ * get borders combo box *
+ *************************/
 
-option_menu = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "menu_borders");
-menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-item_now = gtk_menu_get_active (GTK_MENU (menu));
+sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_borders");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_borders");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_all");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)) == TRUE)
   {
   /*************************************************
    * if the borders option is all, change to faces *
    *************************************************/
 
-  if (item_now == item)
-    gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), GAMGI_PHYS_FACES - 1);
-  gtk_widget_set_sensitive (item, FALSE);
+  if (row == GAMGI_PHYS_ALL - 1)
+    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_FACES - 1);
+  sensitive[GAMGI_PHYS_ALL - 1] = FALSE;
   }
-else gtk_widget_set_sensitive (item, TRUE);
+else sensitive[GAMGI_PHYS_ALL - 1] = TRUE;
 }
 
 static void static_type (GtkWidget *widget, void *data)
@@ -107,24 +114,18 @@ GtkWidget *label_v1, *label_v2, *label_v3;
 GtkWidget *entry_v12, *entry_v13, *entry_v23;
 GtkWidget *label_v12, *label_v13, *label_v23;
 GtkWidget *button_faces, *button_nodes;
-GtkWidget *option_menu, *menu;
-GtkWidget *item_all, *item_faces, *item_none;
-GtkWidget *item_parallelepiped, *item_sphere, *item_projection;
-GtkWidget *item_borders, *item_type;
+GtkWidget *combo;
 char token[GAMGI_ENGINE_TOKEN];
 const char *name;
+gamgi_bool *sensitive;
+int row_type, row_borders;
 
-option_menu = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "menu_type");
-menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-item_type = gtk_menu_get_active (GTK_MENU (menu));
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
+row_type = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
-item_parallelepiped = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_parallelepiped");
-item_sphere = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_sphere");
-item_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_projection");
-
-/****************************
- * set n1, n2, n3 menuitems *
- ****************************/
+/*******************************************
+ * set N1, N2, N3 entries and Faces button *
+ *******************************************/
 
 entry_n1 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_n1");
 entry_n2 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_n2");
@@ -134,9 +135,10 @@ label_n1 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_n1");
 label_n2 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_n2");
 label_n3 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_n3");
 
-if (item_type != item_parallelepiped 
-&& item_type != item_sphere
-&& item_type != item_projection)
+button_faces = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_faces");
+
+if (row_type != GAMGI_PHYS_PARALLELEPIPED - 1 && 
+row_type != GAMGI_PHYS_SPHERE - 1 && row_type != GAMGI_PHYS_PROJECTION - 1)
   {
   /******************
    * enable widgets *
@@ -150,6 +152,8 @@ if (item_type != item_parallelepiped
   gtk_widget_set_sensitive (entry_n2, TRUE);
   gtk_widget_set_sensitive (entry_n3, TRUE);
 
+  gtk_widget_set_sensitive (button_faces, TRUE);
+
   /**********************
    * initialize widgets *
    **********************/
@@ -190,53 +194,51 @@ else
   gtk_widget_set_sensitive (label_n1, FALSE);
   gtk_widget_set_sensitive (label_n2, FALSE);
   gtk_widget_set_sensitive (label_n3, FALSE);
+
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_faces), FALSE);
+  gtk_widget_set_sensitive (button_faces, FALSE);
   }
 
-/*******************
- * set v1 menuitem *
- *******************/
+/*****************************************
+ * set V1, V2, V3, V12, V13, V23 entries *
+ *****************************************/
 
 entry_v1 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v1");
-label_v1 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v1");
-
-if (item_type == item_parallelepiped
-|| item_type == item_sphere)
-  {
-  /*****************
-   * enable widget *
-   *****************/
-
-  gtk_widget_set_sensitive (label_v1, TRUE);
-  gtk_widget_set_sensitive (entry_v1, TRUE);
-  }
-else
-  {
-  /******************
-   * disable widget *
-   ******************/
-
-  gtk_entry_set_text (GTK_ENTRY (entry_v1), "");
-  gtk_widget_set_sensitive (entry_v1, FALSE);
-  gtk_widget_set_sensitive (label_v1, FALSE);
-  }
-
-/***************************************
- * set v2, v3, v12, v13, v23 menuitems *
- ***************************************/
-
 entry_v2 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v2");
 entry_v3 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v3");
 entry_v12 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v12");
 entry_v13 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v13");
 entry_v23 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v23");
 
+label_v1 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v1");
 label_v2 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v2");
 label_v3 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v3");
 label_v12 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v12");
 label_v13 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v13");
 label_v23 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v23");
 
-if (item_type == item_parallelepiped)
+if (row_type == GAMGI_PHYS_PARALLELEPIPED - 1 || 
+row_type == GAMGI_PHYS_SPHERE - 1)
+  {
+  /******************
+   * enable widgets *
+   ******************/
+
+  gtk_widget_set_sensitive (label_v1, TRUE);
+  gtk_widget_set_sensitive (entry_v1, TRUE);
+  }
+else
+  {
+  /*******************
+   * disable widgets *
+   *******************/
+
+  gtk_entry_set_text (GTK_ENTRY (entry_v1), "");
+  gtk_widget_set_sensitive (entry_v1, FALSE);
+  gtk_widget_set_sensitive (label_v1, FALSE);
+  }
+
+if (row_type == GAMGI_PHYS_PARALLELEPIPED - 1)
   {
   /******************
    * enable widgets *
@@ -279,127 +281,70 @@ else
   gtk_widget_set_sensitive (label_v23, FALSE);
   }
 
-/********************
- * set nodes button *
- ********************/
+/***************************************
+ * set Borders combo box, Nodes button *
+ ***************************************/
+
+sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_borders");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_borders");
+row_borders = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 button_nodes = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_nodes");
 
-if (item_type != item_projection)
+if (row_type != GAMGI_PHYS_PARALLELEPIPED - 1 &&
+row_type != GAMGI_PHYS_SPHERE - 1 && row_type != GAMGI_PHYS_PROJECTION - 1)
   {
-  /*****************
-   * enable widget *
-   *****************/
+  /****************************
+   * enable Borders combo box *
+   ****************************/
+
+  sensitive[GAMGI_PHYS_FACES - 1] = TRUE;
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_faces)) == FALSE)
+    sensitive[GAMGI_PHYS_ALL - 1] = TRUE;
+  }
+else
+  {
+  /*****************************
+   * disable Borders combo box *
+   *****************************/
+
+  if (row_borders == GAMGI_PHYS_ALL - 1 || row_borders == GAMGI_PHYS_FACES - 1)
+    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_EDGES - 1);
+  sensitive[GAMGI_PHYS_ALL - 1] = FALSE;
+  sensitive[GAMGI_PHYS_FACES - 1] = FALSE;
+  }
+
+if (row_type != GAMGI_PHYS_PROJECTION - 1)
+  {
+  /***********************
+   * enable Nodes button *
+   ***********************/
 
   gtk_widget_set_sensitive (button_nodes, TRUE);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_nodes), TRUE);
 
-  /*********************
-   * initialize widget *
-   *********************/
+  /***********************
+   * enable Borders None *
+   ***********************/
 
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_nodes)) == FALSE)
-    gtk_button_clicked (GTK_BUTTON (button_nodes));
+  sensitive[GAMGI_PHYS_NONE - 1] = TRUE;
   }
 else
   {
-  /******************
-   * disable widget *
-   ******************/
+  /************************
+   * disable Nodes button *
+   ************************/
 
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_nodes)) == TRUE) 
-    gtk_button_clicked (GTK_BUTTON (button_nodes));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_nodes), FALSE);
   gtk_widget_set_sensitive (button_nodes, FALSE);
-  }
-  
-/********************
- * set faces button *
- ********************/
 
-button_faces = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_faces");
+  /************************
+   * Disable Borders None *
+   ************************/
 
-if (item_type != item_parallelepiped
-&& item_type != item_sphere
-&& item_type != item_projection)
-  {
-  /*****************
-   * enable widget *
-   *****************/
-
-  gtk_widget_set_sensitive (button_faces, TRUE);
-  }
-else
-  {
-  /******************
-   * disable widget *
-   ******************/
-
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_faces), FALSE);
-  gtk_widget_set_sensitive (button_faces, FALSE);
-  }
-
-/***************************
- * set borders option_menu *
- ***************************/
-
-option_menu = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "menu_borders");
-menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-item_borders = gtk_menu_get_active (GTK_MENU (menu));
-
-item_all = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_all");
-item_faces = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_faces");
-item_none = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_none");
-
-if (item_type != item_parallelepiped 
-&& item_type != item_sphere
-&& item_type != item_projection)
-  {
-  /******************
-   * enable widgets *
-   ******************/
-
-  gtk_widget_set_sensitive (item_faces, TRUE);
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_faces)) == FALSE)
-    gtk_widget_set_sensitive (item_all, TRUE);
-  }
-else
-  {
-  /**********************
-   * initialize widgets *
-   **********************/
-
-  if (item_borders == item_all || item_borders == item_faces)
-    gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), GAMGI_PHYS_EDGES - 1);
-
-  /*******************
-   * disable widgets *
-   *******************/
-
-  gtk_widget_set_sensitive (item_all, FALSE);
-  gtk_widget_set_sensitive (item_faces, FALSE);
-  }
-
-if (item_type != item_projection)
-  {
-  /*****************
-   * enable widget *
-   *****************/
-
-  gtk_widget_set_sensitive (item_none, TRUE);
-  }
-else
-  {
-  /*********************
-   * initialize widget *
-   *********************/
-
-  if (item_borders == item_none)
-    gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), GAMGI_PHYS_EDGES - 1);
-
-  /*****************
-   * disable widget *
-   *****************/
-
-  gtk_widget_set_sensitive (item_none, FALSE);
+  if (row_borders == GAMGI_PHYS_NONE - 1)
+    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_EDGES - 1);
+  sensitive[GAMGI_PHYS_NONE - 1] = FALSE;
   }
 }
 
@@ -512,14 +457,13 @@ static void static_ok (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_cell *cell;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *option_menu, *menu;
-GtkWidget *item, *item_now;
 GtkWidget *button;
 GtkWidget *combo;
 GtkEntry *entry;
 const char *name;
 double origin[3], euler[3];
 int o1, o2, o3;
+int row;
 gamgi_enum o4;
 
 cell = gamgi_engine_create_cell ();
@@ -697,39 +641,16 @@ gamgi_io_token_double_scan (name, &euler[2], 0.0, 360.0) == FALSE)
  * get Type page *
  *****************/
 
-/************************
- * get type option menu *
- ************************/
+/********
+ * Type *
+ ********/
 
-option_menu = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "menu_type");
-menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-item_now = gtk_menu_get_active (GTK_MENU (menu));
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
+cell->type = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
-/**********************
- * get type menu item *
- **********************/
-
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_conventional");
-if (item == item_now) cell->type = GAMGI_PHYS_CONVENTIONAL;
-
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_primitive");
-if (item == item_now) cell->type = GAMGI_PHYS_PRIMITIVE;
-
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_wigner");
-if (item == item_now) cell->type = GAMGI_PHYS_WIGNER;
-
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_parallelepiped");
-if (item == item_now) cell->type = GAMGI_PHYS_PARALLELEPIPED;
-
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_sphere");
-if (item == item_now) cell->type = GAMGI_PHYS_SPHERE;
-
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_projection");
-if (item == item_now) cell->type = GAMGI_PHYS_PROJECTION;
-
-/***********************
- * get number of cells *
- ***********************/
+/**************
+ * N1, N2, N3 *
+ **************/
 
 cell->n1 = 1;
 entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_n1");
@@ -764,9 +685,9 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_int_scan (name,
   return;
   }
 
-/****************************************
- * get parallelepiped,sphere parameters *
- ****************************************/
+/*****************************
+ * V1, V2, V3, V12, V13, V23 *
+ *****************************/
 
 entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_v1");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
@@ -985,33 +906,22 @@ if (gamgi_io_token_float_scan (name, &cell->blue, 0.0, 1.0) == FALSE)
 
 entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &cell->object.scale, 0.0, DBL_MAX) == FALSE)
+if (gamgi_io_token_double_scan (name, &cell->object.scale,
+GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
   gamgi_engine_remove_cell (cell);
   return;
   }
 
-/***************************
- * get borders option_menu *
- ***************************/
-
-option_menu = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "menu_borders");
-menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-item_now = gtk_menu_get_active (GTK_MENU (menu));
-
 /*************************
- * get borders menu item *
+ * get borders combo box *
  *************************/
 
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_all");
-if (item == item_now) cell->borders = GAMGI_PHYS_ALL;
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_faces");
-if (item == item_now) cell->borders = GAMGI_PHYS_FACES;
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_edges");
-if (item == item_now) cell->borders = GAMGI_PHYS_EDGES;
-item = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "item_none");
-if (item == item_now) cell->borders = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_borders");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == GAMGI_PHYS_NONE - 1) cell->borders = FALSE;
+else cell->borders = 1 + row;
 
 /**************************************
  * get faces and nodes toggle buttons *
@@ -1085,6 +995,8 @@ char token[GAMGI_ENGINE_TOKEN];
  * Borders, Faces, Nodes in the View page are also modified *
  ************************************************************/
 
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_CONVENTIONAL - 1);
 static_type (NULL, window);
 
 /***********************
@@ -1154,6 +1066,9 @@ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), FALSE);
  * Start View page *
  *******************/
 
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_borders");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, GAMGI_MESA_CELL_R);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
@@ -1184,7 +1099,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), token);
  ***********************************************/
 
 void gamgi_gtk_cell_create_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *entry;
@@ -1242,13 +1157,9 @@ GtkWidget *notebook;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top, *vbox_top_top;
-GtkWidget *option_menu;
-GtkWidget *menu;
-GtkWidget *item;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top, *vbox_top_top;
 GtkWidget *combo;
 GtkListStore *store;
 GtkCellRenderer *renderer;
@@ -1301,7 +1212,7 @@ gtk_widget_show (entry);
 notebook = gtk_notebook_new ();
 gtk_box_pack_start (GTK_BOX (vbox_dialog), notebook, FALSE, FALSE, 0);
 gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
-g_signal_connect (GTK_OBJECT (notebook), "switch_page",
+g_signal_connect (notebook, "switch_page",
 G_CALLBACK (static_switch), window);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
@@ -1310,104 +1221,71 @@ gtk_widget_show (notebook);
  * Symmetry page *
  *****************/
 
-vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new ("Symmetry");
-gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
-gtk_widget_show (vbox_page);
-
 /************************************************
  * symmetry section (including level 2 dialogs) *
  ************************************************/
 
-gamgi_gtk_cell_symmetry (vbox_page, window);
+gamgi_gtk_cell_symmetry (notebook, window);
 
-/**********************************
- * Type page: Type, Length, Angle *
- **********************************/
+/************************************
+ * Volume page: Type, Length, Angle *
+ ************************************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new (" Type ");
+label = gtk_label_new ("Volume");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/********************
- * Type option menu *
- ********************/
+/******************
+ * Type combo box *
+ ******************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-option_menu = gtk_option_menu_new ();
-gtk_box_pack_start (GTK_BOX (hbox_center), option_menu, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "menu_type", option_menu);
-menu = gtk_menu_new ();
+hbox_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
 
-item = gtk_radio_menu_item_new_with_label (NULL, "Conventional");
-gtk_menu_append (GTK_MENU (menu), item);
-g_signal_connect (GTK_OBJECT (item), "activate",
-G_CALLBACK (static_type), window);
-g_object_set_data (G_OBJECT (dialog), "item_conventional", item);
-gtk_widget_show (item);
+label = gtk_label_new ("Type");
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
 
-item = gtk_radio_menu_item_new_with_label (
-gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item)), "Primitive");
-gtk_menu_append (GTK_MENU (menu), item);
-g_signal_connect (GTK_OBJECT (item), "activate",
-G_CALLBACK (static_type), window);
-g_object_set_data (G_OBJECT (dialog), "item_primitive", item);
-gtk_widget_show (item);
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_signal_connect (combo, "changed", G_CALLBACK (static_type), window);
+g_object_set_data (G_OBJECT (dialog), "combo_type", combo);
+gtk_widget_show (combo);
 
-item = gtk_radio_menu_item_new_with_label (
-gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item)), "Wigner-Seitz");
-gtk_menu_append (GTK_MENU (menu), item);
-g_signal_connect (GTK_OBJECT (item), "activate",
-G_CALLBACK (static_type), window);
-g_object_set_data (G_OBJECT (dialog), "item_wigner", item);
-gtk_widget_show (item);
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Conventional", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Primitive", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Wigner-Seitz", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Parallelepiped", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Sphere", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Projection", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
 
-item = gtk_radio_menu_item_new_with_label (
-gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item)), "Parallelepiped");
-gtk_menu_append (GTK_MENU (menu), item);
-g_signal_connect (GTK_OBJECT (item), "activate",
-G_CALLBACK (static_type), window);
-g_object_set_data (G_OBJECT (dialog), "item_parallelepiped", item);
-gtk_widget_show (item);
-
-item = gtk_radio_menu_item_new_with_label (
-gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item)), "Sphere");
-gtk_menu_append (GTK_MENU (menu), item);
-g_signal_connect (GTK_OBJECT (item), "activate",
-G_CALLBACK (static_type), window);
-g_object_set_data (G_OBJECT (dialog), "item_sphere", item);
-gtk_widget_show (item);
-
-item = gtk_radio_menu_item_new_with_label (
-gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item)), "Projection");
-gtk_menu_append (GTK_MENU (menu), item);
-g_signal_connect (GTK_OBJECT (item), "activate",
-G_CALLBACK (static_type), window);
-g_object_set_data (G_OBJECT (dialog), "item_projection", item);
-gtk_widget_show (item);
-
-gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-gtk_widget_show (option_menu);
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
 /*******************************
  * Cell, Length, Angle entries * 
@@ -1436,7 +1314,7 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_n1", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("n1");
+label = gtk_label_new ("N1");
 gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_n1", label);
 gtk_widget_show (label);
@@ -1448,7 +1326,7 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_n2", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("n2");
+label = gtk_label_new ("N2");
 gtk_table_attach (GTK_TABLE (table), label, 4, 5, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_n2", label);
 gtk_widget_show (label);
@@ -1460,7 +1338,7 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_n3", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("n3");
+label = gtk_label_new ("N3");
 gtk_table_attach (GTK_TABLE (table), label, 6, 7, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_n3", label);
 gtk_widget_show (label);
@@ -1480,7 +1358,7 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_v1", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("a");
+label = gtk_label_new ("V1");
 gtk_table_attach (GTK_TABLE (table), label, 2, 3, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_v1", label);
 gtk_widget_show (label);
@@ -1492,7 +1370,7 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_v2", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("b");
+label = gtk_label_new ("V2");
 gtk_table_attach (GTK_TABLE (table), label, 4, 5, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_v2", label);
 gtk_widget_show (label);
@@ -1504,7 +1382,7 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_v3", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("c");
+label = gtk_label_new ("V3");
 gtk_table_attach (GTK_TABLE (table), label, 6, 7, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_v3", label);
 gtk_widget_show (label);
@@ -1524,7 +1402,7 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_v23", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("bc");
+label = gtk_label_new ("V23");
 gtk_table_attach (GTK_TABLE (table), label, 2, 3, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_v23", label);
 gtk_widget_show (label);
@@ -1536,7 +1414,7 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_v13", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("ac");
+label = gtk_label_new ("V13");
 gtk_table_attach (GTK_TABLE (table), label, 4, 5, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_v13", label);
 gtk_widget_show (label);
@@ -1548,7 +1426,7 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_v12", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("ab");
+label = gtk_label_new ("V12");
 gtk_table_attach (GTK_TABLE (table), label, 6, 7, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_v12", label);
 gtk_widget_show (label);
@@ -1560,25 +1438,19 @@ gtk_widget_show (label);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Position");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 10);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 10);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /***************
  * Translation *
  ***************/
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -1595,7 +1467,7 @@ gtk_widget_show (label);
 
 button = gtk_toggle_button_new_with_label ("Align");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_cell_align_translation), window);
 g_object_set_data (G_OBJECT (dialog), "button_translation", button);
 gtk_widget_show (button);
@@ -1653,7 +1525,7 @@ gtk_widget_show (entry);
  ************/
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -1670,7 +1542,7 @@ gtk_widget_show (label);
 
 button = gtk_toggle_button_new_with_label ("Align");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_cell_align_rotation), window);
 g_object_set_data (G_OBJECT (dialog), "button_rotation", button);
 gtk_widget_show (button);
@@ -1730,24 +1602,18 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Origin");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 5);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-vbox_top = gtk_vbox_new (FALSE, 10);
+vbox_top = gtk_vbox_new (FALSE, 20);
 gtk_box_pack_start (GTK_BOX (hbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
@@ -1818,7 +1684,7 @@ gtk_widget_show (hbox_left_left);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_end (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_vectors), window);
 g_object_set_data (G_OBJECT (dialog), "combo_origin_vectors", combo);
 gtk_widget_show (combo);
@@ -1938,25 +1804,19 @@ gtk_widget_show (label);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 5);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /**********************************
  * 1st row: Borders, Faces, Nodes *
  **********************************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 15);
@@ -1971,40 +1831,35 @@ label = gtk_label_new ("Borders");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
-option_menu = gtk_option_menu_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), option_menu, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "menu_borders", option_menu);
-menu = gtk_menu_new ();
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "combo_borders", combo);
+gtk_widget_show (combo);
 
-item = gtk_radio_menu_item_new_with_label (NULL, "All");
-gtk_menu_append (GTK_MENU (menu), item);
-g_object_set_data (G_OBJECT (dialog), "item_all", item);
-gtk_widget_show (item);
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "All", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Faces", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Edges", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "None", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
 
-item = gtk_radio_menu_item_new_with_label (
-gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item)), "Faces");
-gtk_menu_append (GTK_MENU (menu), item);
-g_object_set_data (G_OBJECT (dialog), "item_faces", item);
-gtk_widget_show (item);
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-item = gtk_radio_menu_item_new_with_label (
-gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item)), "Edges");
-gtk_menu_append (GTK_MENU (menu), item);
-g_object_set_data (G_OBJECT (dialog), "item_edges", item);
-gtk_widget_show (item);
-
-item = gtk_radio_menu_item_new_with_label (
-gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item)), "None");
-gtk_menu_append (GTK_MENU (menu), item);
-g_object_set_data (G_OBJECT (dialog), "item_none", item);
-gtk_widget_show (item);
-
-gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-gtk_widget_show (option_menu);
+sensitive = gamgi_gtk_dialog_sensitive_create (4);
+g_object_set_data (G_OBJECT (dialog), "sensitive_borders", sensitive);
+gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
+renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
 
 button = gtk_toggle_button_new_with_label ("Faces");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_faces), window);
 g_object_set_data (G_OBJECT (dialog), "button_faces", button);
 gtk_widget_show (button);
@@ -2019,7 +1874,7 @@ gtk_widget_show (button);
  ******************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (1, 7, FALSE);
@@ -2068,7 +1923,7 @@ gtk_widget_show (entry);
  ******************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
@@ -2096,18 +1951,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
