@@ -12,13 +12,9 @@
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
 #include "gamgi_phys.h"
-#include "gamgi_math.h"
 #include "gamgi_io.h"
 #include "gamgi_global.h"
 
-#include "gamgi_engine_link.h"
-#include "gamgi_engine_unlink.h"
-#include "gamgi_engine_find.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
@@ -374,7 +370,7 @@ int row;
  * get link mode *
  *****************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_link");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 if (row == 1)
@@ -453,7 +449,7 @@ sprintf (token, "%d", GAMGI_PHYS_RCP_SEED);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 }
 
-static void static_link (GtkWidget *widget, void *data)
+static void static_method (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -465,7 +461,7 @@ int row;
  * get link combo box *
  **********************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_link");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /************
@@ -523,7 +519,7 @@ static void static_hierarchy (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *combo_below, *combo_above, *combo_link;
+GtkWidget *combo_below, *combo_above, *combo_method;
 GtkWidget *button;
 GtkWidget *entry;
 gamgi_bool *sensitive;
@@ -531,7 +527,7 @@ gamgi_bool *sensitive;
 combo_above = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_above");
 combo_below = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_below");
 
-combo_link = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_link");
+combo_method = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
 sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_link");
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_above");
@@ -545,9 +541,10 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   gtk_widget_hide (combo_below);
   gtk_combo_box_set_active (GTK_COMBO_BOX (combo_above), 0);
 
-  gtk_combo_box_set_active (GTK_COMBO_BOX (combo_link), 0);
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo_method), 0);
   sensitive[1] = FALSE;
   sensitive[2] = FALSE;
+  sensitive[3] = FALSE;
   }
 else
   {
@@ -561,6 +558,7 @@ else
 
   sensitive[1] = TRUE;
   sensitive[2] = TRUE;
+  sensitive[3] = TRUE;
   }
 
 /**********************
@@ -574,7 +572,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
  * update mode data *
  ********************/
 
-static_link (NULL, window);
+static_method (NULL, window);
 }
 
 /****************** internal function ****************
@@ -993,7 +991,7 @@ if (object == NULL)
  * get link combo box *
  **********************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_link");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /************************************************
@@ -1054,7 +1052,7 @@ gtk_widget_set_size_request (notebook, size.width, size.height);
  * hide pages AFTER measuring notebook size *
  ********************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_link");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
@@ -1086,7 +1084,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), string);
  ****************************************************/
 
 void gamgi_gtk_cell_link_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
@@ -1131,10 +1129,9 @@ GtkWidget *notebook;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top, *vbox_top_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top, *vbox_top_top;
 GtkWidget *combo;
 GtkListStore *store;
 GtkCellRenderer *renderer;
@@ -1186,8 +1183,7 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
-g_signal_connect (GTK_OBJECT (entry), "changed",
-G_CALLBACK (static_cell), window);
+g_signal_connect (entry, "changed", G_CALLBACK (static_cell), window);
 g_object_set_data (G_OBJECT (dialog), "entry_cell", entry);
 gtk_widget_show (entry);
 
@@ -1197,8 +1193,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Global");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
-G_CALLBACK (static_global), window);
+g_signal_connect (button, "toggled", G_CALLBACK (static_global), window);
 g_object_set_data (G_OBJECT (dialog), "button_global", button);
 gtk_widget_show (button);
 
@@ -1219,21 +1214,15 @@ gtk_widget_show (notebook);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" Object ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 15);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 vbox_top_top = gtk_vbox_new (FALSE, 5);
@@ -1253,21 +1242,19 @@ gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 label = gtk_label_new ("Hierarchy");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 button = gtk_radio_button_new_with_label (NULL, "Above");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0); 
-g_signal_connect (GTK_OBJECT (button), "clicked",
-G_CALLBACK (static_hierarchy), window);
+g_signal_connect (button, "clicked", G_CALLBACK (static_hierarchy), window);
 g_object_set_data (G_OBJECT (dialog), "button_above", button);
 gtk_widget_show (button);
 
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Below");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
-G_CALLBACK (static_hierarchy), window);
+g_signal_connect (button, "clicked", G_CALLBACK (static_hierarchy), window);
 g_object_set_data (G_OBJECT (dialog), "button_below", button);
 gtk_widget_show (button);
 
@@ -1342,9 +1329,9 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_object", entry);
 gtk_widget_show (entry);
 
-/********
- * link *
- ********/
+/**********
+ * method *
+ **********/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
@@ -1354,22 +1341,21 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Link");
+label = gtk_label_new ("Method");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
-G_CALLBACK (static_link), window);
-g_object_set_data (G_OBJECT (dialog), "combo_link", combo);
+g_signal_connect (combo, "changed", G_CALLBACK (static_method), window);
+g_object_set_data (G_OBJECT (dialog), "combo_method", combo);
 gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Object", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Crystallographic", -1);
+gtk_list_store_set (store, &iter, 0, "Crystal", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Random", -1);
 gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
@@ -1379,7 +1365,7 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-sensitive = gamgi_gtk_dialog_sensitive_create (3);
+sensitive = gamgi_gtk_dialog_sensitive_create (4);
 g_object_set_data (G_OBJECT (dialog), "sensitive_link", sensitive);
 gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
 renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
@@ -1391,22 +1377,16 @@ renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Position");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "vbox_position", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -1462,8 +1442,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
-G_CALLBACK (static_wyckoff_change), window);
+g_signal_connect (combo, "changed", G_CALLBACK (static_wyckoff_change), window);
 g_object_set_data (G_OBJECT (dialog), "combo_wyckoff", combo);
 gtk_widget_show (combo);
 
@@ -1537,22 +1516,16 @@ gtk_widget_show (label);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Occupancy");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "vbox_occupancy", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /********************
@@ -1694,22 +1667,16 @@ gtk_widget_show (label);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Packing");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "vbox_packing", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 15);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /******************
@@ -1741,21 +1708,19 @@ gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 label = gtk_label_new ("Atom");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 10);
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 5);
 gtk_widget_show (label);
 
 button = gtk_radio_button_new_with_label (NULL, "Radius");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
-G_CALLBACK (static_number), window);
+g_signal_connect (button, "clicked", G_CALLBACK (static_number), window);
 g_object_set_data (G_OBJECT (dialog), "button_radius", button);
 gtk_widget_show (button);
 
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Number");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
-G_CALLBACK (static_number), window);
+g_signal_connect (button, "clicked", G_CALLBACK (static_number), window);
 g_object_set_data (G_OBJECT (dialog), "button_number", button);
 gtk_widget_show (button);
 
@@ -1839,17 +1804,14 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-g_signal_connect (GTK_OBJECT (button), "clicked",
-G_CALLBACK (static_ok), window);
+g_signal_connect (button, "clicked", G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
