@@ -78,7 +78,8 @@ double euler[3];
  *************************************************/
 
 dlist = gamgi_engine_dlist_atom_object (direction->object.object, NULL);
-dlist = gamgi_phys_direction_filter (dlist);
+dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
+dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
 
 /*****************************************************
  * get rotation and translation to transform atoms   *
@@ -174,37 +175,30 @@ static gamgi_enum static_class (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
-GtkWidget *button;
 GtkWidget *combo;
 const char *name;
 int row;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+/***********************************************************
+ * when the direction entry is empty, look for a direction *
+ ***********************************************************/
+
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_direction");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == FALSE) return GAMGI_ENGINE_DIRECTION;
 
-/**************************************
- * when the direction entry is active *
- * and empty, look for a direction    *
- **************************************/
-
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
-gamgi_io_token_check (name) == FALSE) return GAMGI_ENGINE_DIRECTION;
-
-/*********************************
- * select which object to select *
- *********************************/
+/*******************************************
+ * otherwise select which object to select *
+ *******************************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 if (row == GAMGI_GTK_CELL - 1) return GAMGI_ENGINE_CELL;
 if (row == GAMGI_GTK_ATOMS - 1) return GAMGI_ENGINE_ATOM;
 
-/*********************************************
- * this case can only occur when the Global  *
- * button is selected and Reference is Local *
- *********************************************/
+/****************************************************
+ * this case can only occur when Reference is Local *
+ ****************************************************/
 
 return FALSE;
 }
@@ -365,14 +359,16 @@ if (row_autonomy != GAMGI_GTK_ALL - 1 && row_autonomy != GAMGI_GTK_PARTIAL - 1)
   }
 else
   {
-   if (GTK_WIDGET_VISIBLE (vbox) == FALSE)
-     static_start_position (window);
-  gtk_widget_show (vbox);
+  if (GTK_WIDGET_VISIBLE (vbox) == FALSE)
+    {
+    static_start_position (window);
 
-  gtk_widget_set_sensitive (entry, TRUE);
-  gtk_widget_set_sensitive (label, TRUE);
-  sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
-  gtk_entry_set_text (GTK_ENTRY (entry), token);
+    gtk_widget_set_sensitive (entry, TRUE);
+    gtk_widget_set_sensitive (label, TRUE);
+    sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
+    gtk_entry_set_text (GTK_ENTRY (entry), token);
+    }
+  gtk_widget_show (vbox);
   }
 
 /**********************************
@@ -1101,9 +1097,8 @@ gamgi_io_token_float_scan (name, blue, 0.0, 1.0) == FALSE)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE &&
-gamgi_io_token_double_scan (name, scale, 
-GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
+if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
+scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid direction scale", window);
   return FALSE;
@@ -1194,6 +1189,9 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   blue = direction->blue;
   scale = direction->object.scale;
 
+  gamgi_math_position_direction_rotation_get (direction, euler);
+  gamgi_math_position_direction_translation_get (direction, origin);
+
   /***********************************
    * this unneeded initialization    *
    * avoids a O3 compilation warning *
@@ -1396,7 +1394,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
       parent = gamgi_phys_direction_parent (atom1, atom2, window);
       dlist = gamgi_engine_dlist_atom_object (parent, NULL);
-      dlist = gamgi_phys_direction_filter (dlist);
+      dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
+      dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
       }
     else
       {
@@ -1425,9 +1424,9 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   gamgi_math_position_direction_translation_set (direction, origin);
   }
 
-/************************   
- * Redraw gl_area image *
- ************************/
+/*****************************************
+ * Redraw gl_area image and reset dialog *
+ *****************************************/
  
 gtk_widget_queue_draw (window->area);
 static_reset (window);
@@ -1630,29 +1629,29 @@ if (class == GAMGI_ENGINE_DIRECTION)
     gamgi_math_position_direction_translation_get (direction, origin);
 
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-    sprintf (string, "%f", origin[0]);
+    sprintf (string, "%.*f", gamgi->gamgi->length, origin[0]);
     gtk_entry_set_text (GTK_ENTRY (entry), string);
 
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
-    sprintf (string, "%f", origin[1]);
+    sprintf (string, "%.*f", gamgi->gamgi->length, origin[1]);
     gtk_entry_set_text (GTK_ENTRY (entry), string);
 
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
-    sprintf (string, "%f", origin[2]);
+    sprintf (string, "%.*f", gamgi->gamgi->length, origin[2]);
     gtk_entry_set_text (GTK_ENTRY (entry), string);
 
     gamgi_math_position_direction_rotation_get (direction, euler);
 
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
-    sprintf (string, "%f", euler[0]);
+    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[0]);
     gtk_entry_set_text (GTK_ENTRY (entry), string);
 
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
-    sprintf (string, "%f", euler[1]);
+    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[1]);
     gtk_entry_set_text (GTK_ENTRY (entry), string);
 
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
-    sprintf (string, "%f", euler[2]);
+    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[2]);
     gtk_entry_set_text (GTK_ENTRY (entry), string);
     }
 
@@ -1702,7 +1701,7 @@ else return;
 }
 
 void gamgi_gtk_direction_modify_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
@@ -1732,10 +1731,9 @@ void gamgi_gtk_direction_modify (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog;
 GtkWidget *notebook;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top, *vbox_top_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top, *vbox_top_top;
 GtkWidget *entry;
 GtkWidget *label;
 GtkWidget *button;
@@ -1790,7 +1788,7 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_cell), window);
 g_object_set_data (G_OBJECT (dialog), "entry_direction", entry);
 gtk_widget_show (entry);
@@ -1801,7 +1799,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Global");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_global), window);
 g_object_set_data (G_OBJECT (dialog), "button_global", button);
 gtk_widget_show (button);
@@ -1823,26 +1821,11 @@ gtk_widget_show (notebook);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" Type ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-/********************************************************
- * vbox_frame is not centered, to avoid small shifts    *
- * in the reference position when frame contents change *
- ********************************************************/
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
-
 vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /********
@@ -1863,7 +1846,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_reference), window);
 g_object_set_data (G_OBJECT (dialog), "combo_reference", combo);
 gtk_widget_show (combo);
@@ -1907,7 +1890,7 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_cell), window);
 g_object_set_data (G_OBJECT (dialog), "entry_cell", entry);
 gtk_widget_show (entry);
@@ -1983,7 +1966,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_vectors), window);
 g_object_set_data (G_OBJECT (dialog), "combo_vectors", combo);
 gtk_widget_show (combo);
@@ -2048,22 +2031,16 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Projection");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "vbox_projection", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /**************
@@ -2147,47 +2124,37 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" Line ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "vbox_line", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /********
  * Link *
  ********/
 
-vbox_top_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_top), vbox_top_top, FALSE, FALSE, 0);
-gtk_widget_show (vbox_top_top);
-
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
+table = gtk_table_new (2, 2, FALSE);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
+gtk_widget_show (table);
 
 label = gtk_label_new ("Autonomy");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+gtk_table_attach (GTK_TABLE (table), combo, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 5);
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_autonomy), window);
 g_object_set_data (G_OBJECT (dialog), "combo_autonomy", combo);
 gtk_widget_show (combo);
@@ -2212,21 +2179,13 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  * Thickness *
  *************/
 
-hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
-gtk_widget_show (hbox_center);
-
-hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
-
 label = gtk_label_new ("Thickness");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 5, 0);
 g_object_set_data (G_OBJECT (dialog), "label_thickness", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
+gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_thickness", entry);
@@ -2344,26 +2303,20 @@ gtk_widget_show (label);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Position");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "vbox_position", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 10);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 10);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /**********
  * Origin *
  **********/
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -2420,7 +2373,7 @@ gtk_widget_show (entry);
  *********/
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -2479,21 +2432,15 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 20);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /*********
@@ -2579,18 +2526,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
