@@ -145,13 +145,13 @@ gamgi_gtk_help_dialog_import ("Help Interfaces File",
 static void static_interfaces_file_import (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces File Import", 
-"interfaces/file/import", data, 0, 0);
+"interfaces/file/import", data, 2, 1, "location", "filters");
 }
 
 static void static_interfaces_file_export (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces File Export", 
-"interfaces/file/export", data, 0, 0);
+"interfaces/file/export", data, 2, 1, "location", "filters");
 }
 
 static void static_interfaces_window (void *data)
@@ -237,7 +237,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Light",
 static void static_interfaces_light_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Light Create", 
-"interfaces/light/create", data, 3, 1, "type", "color", "attenuation");
+"interfaces/light/create", data, 3, 1, "geometry", "color", "attenuation");
 }
 
 static void static_interfaces_light_select (void *data)
@@ -255,7 +255,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Light Link",
 static void static_interfaces_light_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Light Modify",
-"interfaces/light/modify", data, 2, 1, "strength", "view");
+"interfaces/light/modify", data, 3, 1, "geometry", "color", "attenuation");
 }
 
 static void static_interfaces_light_remove (void *data)
@@ -345,7 +345,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Cell",
 static void static_interfaces_cell_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Cell Create", 
-"interfaces/cell/create", data, 5, 1, "symmetry", "type",
+"interfaces/cell/create", data, 5, 1, "symmetry", "volume",
 "position", "origin", "view");
 }
 
@@ -371,7 +371,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Cell Link RCP",
 static void static_interfaces_cell_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Cell Modify", 
-"interfaces/cell/modify", data, 5, 1, "symmetry", "type",
+"interfaces/cell/modify", data, 5, 1, "symmetry", "volume",
 "position", "origin", "view");
 }
 
@@ -505,8 +505,15 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Group",
 
 static void static_interfaces_group_create (void *data)
 {
-gamgi_gtk_help_dialog_import ("Help Interfaces Group Create", 
-"interfaces/group/create", data, 0, 0);
+gamgi_gtk_help_dialog_import ("Help Interfaces Group Create",
+"interfaces/group/create", data, 4, 1, "type", "scope",
+"tolerance", "view");
+}
+
+static void static_interfaces_group_create_polytope (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Group Create Polytope",
+"interfaces/group/create_polytope", data, 0, 0);
 }
 
 static void static_interfaces_group_select (void *data)
@@ -524,7 +531,14 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Group Link",
 static void static_interfaces_group_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Group Modify",
-"interfaces/group/modify", data, 3, 1, "length", "angle", "torsion");
+"interfaces/group/modify", data, 4, 1, "type", "scope", 
+"tolerance", "view");
+}
+
+static void static_interfaces_group_modify_polytope (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Group Modify Polytope",
+"interfaces/group/modify_polytope", data, 0, 0);
 }
 
 static void static_interfaces_group_measure (void *data)
@@ -656,7 +670,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Atom",
 static void static_interfaces_atom_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Atom Create", 
-"interfaces/atom/create", data, 5, 1, "element", "property",
+"interfaces/atom/create", data, 5, 1, "type", "property",
 "analysis", "position", "view");
 }
 
@@ -669,7 +683,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Atom Copy",
 static void static_interfaces_atom_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Atom Select", 
-"interfaces/atom/select", data, 0, 0);
+"interfaces/atom/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_atom_link (void *data)
@@ -681,8 +695,8 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Atom Link",
 static void static_interfaces_atom_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Atom Modify", 
-"interfaces/atom/modify", data, 5, 1, "element", "property",
-"analysis", "position", "view");
+"interfaces/atom/modify", data, 7, 1, "type", "property",
+"analysis", "position", "view", "length", "angle");
 }
 
 static void static_interfaces_atom_measure (void *data)
@@ -700,7 +714,8 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Atom Remove",
 static void static_interfaces_atom_config (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Atom Config", 
-"interfaces/atom/config", data, 0, 0);
+"interfaces/atom/config", data, 3, 1, "element",
+"analysis", "view");
 }
 
 static void static_interfaces_bond (void *data)
@@ -712,7 +727,8 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Bond",
 static void static_interfaces_bond_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Bond Create", 
-"interfaces/bond/create", data, 4, 1, "mode", "length", "type", "view");
+"interfaces/bond/create", data, 4, 1, "method", "length",
+"property", "view");
 }
 
 static void static_interfaces_bond_select (void *data)
@@ -730,7 +746,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Bond Link",
 static void static_interfaces_bond_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Bond Modify", 
-"interfaces/bond/modify", data, 2, 1, "type", "view");
+"interfaces/bond/modify", data, 2, 1, "property", "view");
 }
 
 static void static_interfaces_bond_remove (void *data)
@@ -1383,14 +1399,16 @@ static_row (store, &iter3, "Voronoi", static_interfaces_molecule_measure_voronoi
 static_row (store, &iter2, "Remove", static_interfaces_molecule_remove);
 
 iter2 = static_row (store, &iter1, "Group", static_interfaces_group);
-static_row (store, &iter2, "Create", static_interfaces_group_create);
+iter3 = static_row (store, &iter2, "Create", static_interfaces_group_create);
+static_row (store, &iter3, "Polytope", static_interfaces_group_create_polytope);
 static_row (store, &iter2, "Select", static_interfaces_group_select);
 static_row (store, &iter2, "Link", static_interfaces_group_link);
 iter3 = static_row (store, &iter2, "Measure", static_interfaces_group_measure);
 static_row (store, &iter3, "Geometry", static_interfaces_group_measure_geometry);
 static_row (store, &iter3, "Symmetry", static_interfaces_group_measure_symmetry);
 static_row (store, &iter3, "Voronoi", static_interfaces_group_measure_voronoi);
-static_row (store, &iter2, "Modify", static_interfaces_group_modify);
+iter3 = static_row (store, &iter2, "Modify", static_interfaces_group_modify);
+static_row (store, &iter3, "Polytope", static_interfaces_group_modify_polytope);
 static_row (store, &iter2, "Remove", static_interfaces_group_remove);
 
 iter2 = static_row (store, &iter1, "Plane", static_interfaces_plane);
@@ -1580,7 +1598,7 @@ gtk_widget_set_size_request (treeview,
 GAMGI_GTK_HELP_TOPIC_WIDTH, GAMGI_GTK_HELP_TOPIC_HEIGHT);
 selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
-g_signal_connect (GTK_OBJECT (treeview), "row-activated",
+g_signal_connect (treeview, "row-activated",
 G_CALLBACK (static_activated), window);
 g_object_set_data (G_OBJECT (dialog), "treeview", treeview);
 gtk_widget_show (treeview);
@@ -1603,17 +1621,15 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
