@@ -31,7 +31,7 @@ static void static_press (gamgi_object *object, void *data);
  **********************/
 
 void gamgi_gtk_layer_copy_press (gamgi_window *window_mouse,  
-int x, int y, gamgi_window *window_dialog);
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog);
 
 void gamgi_gtk_layer_copy (GtkWidget *widget, void *data);
 
