@@ -1058,9 +1058,9 @@ if (light->position[3] == 1.0)
 
   if (light->angle != 180.0)
     {
-    /******************************
-     * spot light: read direction *
-     ******************************/
+    /*********************************************************
+     * spot light: read direction, angle, radial attenuation *
+     *********************************************************/
 
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_direction_x");
     sprintf (string, "%.*f", gamgi->gamgi->length, light->direction[0]);
@@ -1167,7 +1167,7 @@ static_light (window);
  ***********************************************/
  
 void gamgi_gtk_light_modify_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button; 
@@ -1201,10 +1201,9 @@ GtkWidget *notebook;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top;
 GtkWidget *combo;
 GtkListStore *store;
 GtkCellRenderer *renderer;
@@ -1264,7 +1263,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Global");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_global), window);
 g_object_set_data (G_OBJECT (dialog), "button_global", button);
 gtk_widget_show (button);
@@ -1279,28 +1278,22 @@ gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
-/*************
- * Type page *
- *************/
+/*****************
+ * Geometry page *
+ *****************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new (" Type ");
+label = gtk_label_new ("Geometry");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
-
-vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+vbox_top = gtk_vbox_new (FALSE, 15);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /****************
@@ -1315,9 +1308,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
+label = gtk_label_new ("Type");
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_default), window);
 g_object_set_data (G_OBJECT (dialog), "combo_light", combo);
 gtk_widget_show (combo);
@@ -1433,21 +1430,15 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" Color ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (4, 4, FALSE);
@@ -1560,21 +1551,15 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Attenuation");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /*********
@@ -1617,7 +1602,7 @@ g_object_set_data (G_OBJECT (dialog), "entry_constant", entry);
 gtk_widget_show (entry);
 
 entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 2, 3, GTK_FILL, GTK_FILL, 5, 0);
+gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 2, 3, GTK_FILL, GTK_FILL, 5, 5);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "entry_linear", entry);
@@ -1656,18 +1641,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
