@@ -20,7 +20,7 @@ static void static_ok (GtkWidget *widget, void *data);
  **********************/
 
 void gamgi_gtk_molecule_select_press (gamgi_window *window_mouse,    
-int x, int y, gamgi_window *window_dialog);
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog);
 
 void gamgi_gtk_molecule_select (GtkWidget *widget, void *data);
 
