@@ -49,35 +49,38 @@ switch (offset)
 
   case 2:
   if (style == GAMGI_MESA_WIRED) return GAMGI_IO_HERSHEY_SANS;
-  if (style == GAMGI_MESA_SOLID) return GAMGI_IO_VERA_SANS;
+  if (style == GAMGI_MESA_SOLID) return GAMGI_IO_DEJAVU_SANS;
 
   case 3:
   if (style == GAMGI_MESA_WIRED) return GAMGI_IO_HERSHEY_SANS_BOLD;
-  if (style == GAMGI_MESA_SOLID) return GAMGI_IO_VERA_SANS_BOLD;
+  if (style == GAMGI_MESA_SOLID) return GAMGI_IO_DEJAVU_SANS_BOLD;
 
-  case 4: return GAMGI_IO_VERA_SANS_ITALIC;
-  case 5: return GAMGI_IO_VERA_SANS_BOLD_ITALIC;
+  case 4: return GAMGI_IO_DEJAVU_SANS_ITALIC;
+  case 5: return GAMGI_IO_DEJAVU_SANS_BOLD_ITALIC;
 
   case 6:
   if (style == GAMGI_MESA_WIRED) return GAMGI_IO_HERSHEY_SERIF;
-  if (style == GAMGI_MESA_SOLID) return GAMGI_IO_VERA_SERIF;
+  if (style == GAMGI_MESA_SOLID) return GAMGI_IO_DEJAVU_SERIF;
 
   case 7:
   if (style == GAMGI_MESA_WIRED) return GAMGI_IO_HERSHEY_SERIF_BOLD;
-  if (style == GAMGI_MESA_SOLID) return GAMGI_IO_VERA_SERIF_BOLD;
+  if (style == GAMGI_MESA_SOLID) return GAMGI_IO_DEJAVU_SERIF_BOLD;
 
-  case 8: return GAMGI_IO_HERSHEY_SCRIPT;
-  case 9: return GAMGI_IO_HERSHEY_SCRIPT_BOLD;
-  case 10: return GAMGI_IO_HERSHEY_GOTHIC_ENGLISH;
-  case 11: return GAMGI_IO_HERSHEY_GOTHIC_GERMAN;
-  case 12: return GAMGI_IO_HERSHEY_GOTHIC_ITALIAN;
-  case 13: return GAMGI_IO_HERSHEY_SYMBOL_SANS;
-  case 14: return GAMGI_IO_HERSHEY_SYMBOL_SERIF;
-  case 15: return GAMGI_IO_HERSHEY_SYMBOL_SERIF_BOLD;
-  case 16: return GAMGI_IO_VERA_MONO;
-  case 17: return GAMGI_IO_VERA_MONO_BOLD;
-  case 18: return GAMGI_IO_VERA_MONO_ITALIC;
-  case 19: return GAMGI_IO_VERA_MONO_BOLD_ITALIC;
+  case 8: return GAMGI_IO_DEJAVU_SERIF_ITALIC;
+  case 9: return GAMGI_IO_DEJAVU_SERIF_BOLD_ITALIC;
+
+  case 10: return GAMGI_IO_HERSHEY_SCRIPT;
+  case 11: return GAMGI_IO_HERSHEY_SCRIPT_BOLD;
+  case 12: return GAMGI_IO_HERSHEY_GOTHIC_ENGLISH;
+  case 13: return GAMGI_IO_HERSHEY_GOTHIC_GERMAN;
+  case 14: return GAMGI_IO_HERSHEY_GOTHIC_ITALIAN;
+  case 15: return GAMGI_IO_HERSHEY_SYMBOL_SANS;
+  case 16: return GAMGI_IO_HERSHEY_SYMBOL_SERIF;
+  case 17: return GAMGI_IO_HERSHEY_SYMBOL_SERIF_BOLD;
+  case 18: return GAMGI_IO_DEJAVU_MONO;
+  case 19: return GAMGI_IO_DEJAVU_MONO_BOLD;
+  case 20: return GAMGI_IO_DEJAVU_MONO_ITALIC;
+  case 21: return GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC;
   }
 
 /**********************************************
@@ -683,8 +686,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &scale, 0.0, DBL_MAX) == FALSE)
+  if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
+  &scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
     return;
@@ -925,7 +928,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), string);
  ***********************************************/
 
 void gamgi_gtk_text_modify_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
@@ -963,7 +966,7 @@ GtkWidget *button;
 GtkWidget *label;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top;
 GtkWidget *combo;
 GtkListStore *store;
 GtkCellRenderer *renderer;
@@ -1023,7 +1026,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Global");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_global), window);
 g_object_set_data (G_OBJECT (dialog), "button_global", button);
 gtk_widget_show (button);
@@ -1045,21 +1048,20 @@ gtk_widget_show (notebook);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Contents");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
+
 frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), frame, TRUE, TRUE, 0);
 gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
 gtk_widget_show (frame);
 
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
-
 scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-gtk_container_add (GTK_CONTAINER (vbox_frame), scrolled_window);
+gtk_container_add (GTK_CONTAINER (frame), scrolled_window);
 gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 gtk_widget_show (scrolled_window);
@@ -1081,25 +1083,19 @@ gtk_widget_show (text);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Position");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 10);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 10);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /**********
  * Origin *
  **********/
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -1116,7 +1112,7 @@ gtk_widget_show (label);
 
 button = gtk_radio_button_new_with_label (NULL, "Absolute");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_origin), window);
 g_object_set_data (G_OBJECT (dialog), "button_translation_absolute", button);
 gtk_widget_show (button);
@@ -1124,7 +1120,7 @@ gtk_widget_show (button);
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Relative");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_origin), window);
 g_object_set_data (G_OBJECT (dialog), "button_translation_relative", button);
 gtk_widget_show (button);
@@ -1175,7 +1171,7 @@ gtk_widget_show (entry);
  *********/
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -1192,7 +1188,7 @@ gtk_widget_show (label);
 
 button = gtk_radio_button_new_with_label (NULL, "Absolute");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_angle), window);
 g_object_set_data (G_OBJECT (dialog), "button_rotation_absolute", button);
 gtk_widget_show (button);
@@ -1200,7 +1196,7 @@ gtk_widget_show (button);
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Relative");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_angle), window);
 g_object_set_data (G_OBJECT (dialog), "button_rotation_relative", button);
 gtk_widget_show (button);
@@ -1253,25 +1249,19 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 5);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /*****************************
  * 1st row: font Style,Faces *
  *****************************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 15);
@@ -1292,7 +1282,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_style), window);
 g_object_set_data (G_OBJECT (dialog), "combo_style", combo);
 gtk_widget_show (combo);
@@ -1340,7 +1330,7 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  ******************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (1, 7, FALSE);
@@ -1389,7 +1379,7 @@ gtk_widget_show (entry);
  *********/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
@@ -1417,18 +1407,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
