@@ -140,34 +140,43 @@
 #include "gamgi_mesa_rotate.h"
 #include "gamgi_mesa_scale.h"
 
-static void static_menu_position (GtkMenu *menu, int *x, int *y, 
-gamgi_bool *push, void *data)
+static void static_menu_position (GtkMenu *menu,
+int *x, int *y, gamgi_bool *push, void *data)
 {
-GtkWidget *button;
+GtkRequisition size;
+GtkWidget *button  = (GtkWidget *) data;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (menu), "button");
+/********************************
+ * set position for pop up menu *
+ ********************************/
 
-/*
-int w, h;
-
-gdk_window_get_size (button->window, &w, &h);
+gtk_widget_size_request (button, &size);
 gdk_window_get_origin (button->window, x, y);
-*x += 4;
-*y += h;
-*/
+*x += button->allocation.x;
+*y += button->allocation.y + size.height / 2 ;
+
+/****************************
+ * set size for pop up menu *
+ ****************************/
+
+gtk_widget_size_request (GTK_WIDGET (menu), &size);
+size.width = GAMGI_GTK_WINDOW_WIDTH / 10 + 10;
+gtk_widget_set_size_request (GTK_WIDGET (menu), size.width, size.height);
+
+*push = TRUE;
 }
 
-static int static_menu (GtkMenu *menu, GdkEventButton *event)
+static int static_menu (GtkWidget *button, GdkEventButton *event, void *data)
 {
-gamgi_window *window;
-GtkWidget *button;
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *menu;
 int class;
 int mask;
 
+menu = (GtkWidget *) g_object_get_data (G_OBJECT (button), "menu");
+
 if (event->type == GDK_BUTTON_PRESS)
   {
-  window = (gamgi_window *) g_object_get_data (G_OBJECT (menu), "window");
-
   /*************************************************************
    * convert 1,2,3 to BUTTON1_MASK, BUTTON2_MASK, BUTTON3_MASK *
    *************************************************************/
@@ -175,23 +184,21 @@ if (event->type == GDK_BUTTON_PRESS)
   mask = gamgi_gtk_dialog_button_mask (event->button);
   if (mask == gamgi->gamgi->button1)
     {
-    window->selection = FALSE;
+    window->class = FALSE;
 
-    button = (GtkWidget *) g_object_get_data (G_OBJECT (menu), "button");
-
-    gtk_menu_popup (menu, NULL, NULL, static_menu_position, 
-    NULL, event->button, event->time);
+    gtk_menu_popup (GTK_MENU (menu), NULL, NULL, static_menu_position, 
+    button, event->button, event->time);
     }
   else if (mask == gamgi->gamgi->button2) 
     {
     class = GAMGI_POINTER_TO_INT (g_object_get_data (G_OBJECT (menu), "select"));
 
     if ((class != GAMGI_ENGINE_GAMGI && class != GAMGI_ENGINE_WINDOW &&
-    class != GAMGI_ENGINE_LAYER) || window->selection != class)
-      window->selection = class;
+    class != GAMGI_ENGINE_LAYER) || window->class != class)
+      window->class = class;
     else
       {
-      window->selection = FALSE;
+      window->class = FALSE;
 
       if (class == GAMGI_ENGINE_GAMGI)
         gamgi_gtk_object_focus_global ();
@@ -244,8 +251,7 @@ gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 gtk_widget_show (item);
 
 if (function != NULL)
-  g_signal_connect (GTK_OBJECT (item), 
-  "activate", G_CALLBACK (function), window);
+  g_signal_connect (item, "activate", G_CALLBACK (function), window);
 
 return item;
 }
@@ -264,7 +270,7 @@ gamgi_callback2 handler_function, gamgi_window *window)
 GtkWidget *button = gamgi_gtk_dialog_button_create (name, NULL);
 
 gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (handler_function), window);
 gtk_widget_show (button);
 
@@ -436,8 +442,7 @@ switch (window->mode)
   return;
   }
 
-gamgi_gtk_statusbar_message_show (window,
-string, "red", GAMGI_GTK_STATUSBAR_TIME_PRESS);
+gamgi_gtk_statusbar_message_show (window, string, NULL, -1);
 }
 
 static void static_ruler_motion (GtkWidget *widget,
@@ -482,8 +487,7 @@ switch (window->mode)
   return;
   }
 
-gamgi_gtk_statusbar_message_show (window, 
-string, "black", GAMGI_GTK_STATUSBAR_TIME_MOTION);
+gamgi_gtk_statusbar_message_show (window, string, NULL, -1);
 }
 
 static void static_ruler_on (gamgi_window *window, gamgi_enum mode)
@@ -491,14 +495,18 @@ static void static_ruler_on (gamgi_window *window, gamgi_enum mode)
 GdkColor color;
 GtkWidget *rotate, *move, *scale;
 GtkWidget *button = NULL;
+GtkWidget *label;
 
 rotate = (GtkWidget *) g_object_get_data (G_OBJECT (window->window), "button_rotate");
 move = (GtkWidget *) g_object_get_data (G_OBJECT (window->window), "button_move");
 scale = (GtkWidget *) g_object_get_data (G_OBJECT (window->window), "button_scale");
 
-gamgi_gtk_statusbar_color (GTK_BIN (rotate)->child, NULL, window);
-gamgi_gtk_statusbar_color (GTK_BIN (move)->child, NULL, window);
-gamgi_gtk_statusbar_color (GTK_BIN (scale)->child, NULL, window);
+label = gtk_bin_get_child (GTK_BIN (rotate));
+gamgi_gtk_statusbar_color (label, NULL, window);
+label = gtk_bin_get_child (GTK_BIN (move));
+gamgi_gtk_statusbar_color (label, NULL, window);
+label = gtk_bin_get_child (GTK_BIN (scale));
+gamgi_gtk_statusbar_color (scale, NULL, window);
 
 /*******************************************
  * mode must be only rotate, move or scale *
@@ -512,7 +520,8 @@ if (mode == GAMGI_GTK_SCALE) button = scale;
 
 gamgi_gtk_dialog_color (&color,
 GAMGI_GTK_ACTIVE_R, GAMGI_GTK_ACTIVE_G, GAMGI_GTK_ACTIVE_B);
-gamgi_gtk_dialog_color_fg (GTK_BIN (button)->child, color);
+label = gtk_bin_get_child (GTK_BIN (button));
+gamgi_gtk_dialog_color_fg (label, color);
 
 static_ruler_motion (NULL, NULL, window);
 }
@@ -520,13 +529,17 @@ static_ruler_motion (NULL, NULL, window);
 static void static_ruler_off (gamgi_window *window)
 {
 GtkWidget *button;
+GtkWidget *label;
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (window->window), "button_rotate");
-gamgi_gtk_statusbar_color (GTK_BIN (button)->child, NULL, window);
+label = gtk_bin_get_child (GTK_BIN (button));
+gamgi_gtk_statusbar_color (label, NULL, window);
 button = (GtkWidget *) g_object_get_data (G_OBJECT (window->window), "button_move");
-gamgi_gtk_statusbar_color (GTK_BIN (button)->child, NULL, window);
+label = gtk_bin_get_child (GTK_BIN (button));
+gamgi_gtk_statusbar_color (label, NULL, window);
 button = (GtkWidget *) g_object_get_data (G_OBJECT (window->window), "button_scale");
-gamgi_gtk_statusbar_color (GTK_BIN (button)->child, NULL, window);
+label = gtk_bin_get_child (GTK_BIN (button));
+gamgi_gtk_statusbar_color (label, NULL, window);
 
 static_ruler_start (window);
 gamgi_gtk_statusbar_message_timeout (window);
@@ -540,7 +553,7 @@ GtkWidget *label;
 GdkColor color;
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (window->window), "button_axes");
-label = GTK_BIN (button)->child;
+label = gtk_bin_get_child (GTK_BIN (button));
 
 if (window->axes == FALSE)
   {
@@ -566,55 +579,36 @@ static void static_rotate (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 
+window->total = 0.0;
+
 if (window->mode == GAMGI_GTK_ROTATE)
   static_ruler_off (window);
 else
   static_ruler_on (window, GAMGI_GTK_ROTATE);
-
-window->total = 0.0;
 }
 
 static void static_move (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 
+window->total = 0.0;
+
 if (window->mode == GAMGI_GTK_MOVE)
   static_ruler_off (window);
 else
   static_ruler_on (window, GAMGI_GTK_MOVE);
-
-window->total = 0.0;
 }
 
 static void static_scale (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 
+window->total = 1.0;
+
 if (window->mode == GAMGI_GTK_SCALE)
   static_ruler_off (window);
 else
   static_ruler_on (window, GAMGI_GTK_SCALE);
-
-window->total = 1.0;
-}
-
-static void static_console (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-static int flag = 1;
-Display *display;
-
-display = GDK_WINDOW_XDISPLAY (window->window->window);
-if (flag > 0)
-  XRaiseWindow(display, gamgi->console);
-else
-  XLowerWindow(display, gamgi->console);
-flag *= -1;   
-}
-
-static void static_shell (GtkWidget *widget, void *data)
-{
-system (GAMGI_GTK_XTERM);
 }
 
 void gamgi_gtk_window_create (gamgi_window *window, gamgi_layer *layer)
@@ -629,7 +623,6 @@ GtkWidget *vbox;
 GtkWidget *hbox;
 GtkWidget *event_box;
 GtkWidget *item;
-GtkAdjustment *adjustment;
 GtkAccelGroup *group;
 char string[2 * GAMGI_ENGINE_TOKEN];
 
@@ -646,10 +639,10 @@ gtk_window_set_default_size (GTK_WINDOW (window->window), window->width, window-
 gtk_widget_set_size_request (window->window, GAMGI_GTK_WINDOW_WIDTH_MIN,
 GAMGI_GTK_WINDOW_HEIGHT_MIN);
 
-g_signal_connect (GTK_OBJECT (window->window), 
+g_signal_connect (window->window, 
 "delete_event", G_CALLBACK (static_delete), window);
-g_signal_connect_after (GTK_OBJECT (window->window), 
-"key_press_event", G_CALLBACK(gamgi_gtk_handle_key_press), window);
+g_signal_connect_after (window->window, 
+"key_press_event", G_CALLBACK (gamgi_gtk_handle_key_press), window);
 
 vbox_main = gtk_vbox_new (FALSE, 0);
 gtk_container_add (GTK_CONTAINER (window->window), vbox_main);
@@ -674,12 +667,12 @@ gtk_widget_show (table);
 
 button = gamgi_gtk_dialog_button_create ("Gamgi", NULL);
 static_button_menu (table, button, 0, 1, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_gamgi", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_GAMGI);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT (button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT (menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "About", NULL, gamgi_gtk_gamgi_about, window);
 static_item_insert (menu, "Reset", NULL, gamgi_gtk_gamgi_reset, window);
@@ -697,7 +690,7 @@ gtk_widget_add_accelerator (item, "activate",
 group, GDK_C, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", NULL, gamgi_gtk_gamgi_config, window);
@@ -708,18 +701,18 @@ static_item_insert (menu, "Config", NULL, gamgi_gtk_gamgi_config, window);
 
 button = gamgi_gtk_dialog_button_create ("File", NULL);
 static_button_menu (table, button, 1, 2, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_file", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) FALSE);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT (button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT (menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Import", NULL, gamgi_gtk_file_import, window);
 static_item_insert (menu, "Export", NULL, gamgi_gtk_file_export, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -730,12 +723,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Window", NULL);
 static_button_menu (table, button, 2, 3, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_window", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_WINDOW);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, static_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_window_copy, window);
@@ -745,7 +738,7 @@ static_item_insert (menu, "Modify", "grey", gamgi_gtk_window_modify, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_window_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", NULL, gamgi_gtk_window_config, window);
@@ -756,12 +749,12 @@ static_item_insert (menu, "Config", NULL, gamgi_gtk_window_config, window);
 
 button = gamgi_gtk_dialog_button_create ("Layer", NULL);
 static_button_menu (table, button, 3, 4, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_layer", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_LAYER);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_layer_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_layer_copy, window);
@@ -771,7 +764,7 @@ static_item_insert (menu, "Modify", NULL, gamgi_gtk_layer_modify, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_layer_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", NULL, gamgi_gtk_layer_config, window);
@@ -782,12 +775,12 @@ static_item_insert (menu, "Config", NULL, gamgi_gtk_layer_config, window);
 
 button = gamgi_gtk_dialog_button_create ("Light", NULL);
 static_button_menu (table, button, 4, 5, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_light", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_LIGHT);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_light_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_light_copy, window);
@@ -797,7 +790,7 @@ static_item_insert (menu, "Modify", NULL, gamgi_gtk_light_modify, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_light_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", NULL, gamgi_gtk_light_config, window);
@@ -808,12 +801,12 @@ static_item_insert (menu, "Config", NULL, gamgi_gtk_light_config, window);
 
 button = gamgi_gtk_dialog_button_create ("Assembly", NULL);
 static_button_menu (table, button, 5, 6, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_assembly", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_ASSEMBLY);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_assembly_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_assembly_copy, window);
@@ -823,7 +816,7 @@ static_item_insert (menu, "Modify", "grey", gamgi_gtk_assembly_modify, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_assembly_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -832,15 +825,14 @@ static_item_insert (menu, "Config", "grey", NULL, window);
  * setup graph menu *
  ********************/
 
-/* setup graph menu */
 button = gamgi_gtk_dialog_button_create ("Graph", NULL);
 static_button_menu (table, button, 6, 7, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_graph", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_GRAPH);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", "grey", gamgi_gtk_graph_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_graph_copy, window);
@@ -850,7 +842,7 @@ static_item_insert (menu, "Modify", "grey", gamgi_gtk_graph_modify, window);
 static_item_insert (menu, "Remove", "grey", gamgi_gtk_graph_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -861,12 +853,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Shape", NULL);
 static_button_menu (table, button, 7, 8, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_shape", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_SHAPE);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", "grey", gamgi_gtk_shape_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_shape_copy, window);
@@ -876,7 +868,7 @@ static_item_insert (menu, "Modify", "grey", gamgi_gtk_shape_modify, window);
 static_item_insert (menu, "Remove", "grey", gamgi_gtk_shape_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -887,12 +879,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Arrow", NULL);
 static_button_menu (table, button, 8, 9, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_arrow", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_ARROW);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", "grey", gamgi_gtk_arrow_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_arrow_copy, window);
@@ -902,7 +894,7 @@ static_item_insert (menu, "Modify", "grey", gamgi_gtk_arrow_modify, window);
 static_item_insert (menu, "Remove", "grey", gamgi_gtk_arrow_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -913,12 +905,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Cell", NULL);
 static_button_menu (table, button, 9, 10, 0, 1);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_cell", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_CELL);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_cell_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_cell_copy, window);
@@ -930,7 +922,7 @@ static_item_insert (menu, "Animate", "grey", gamgi_gtk_cell_animate, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_cell_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -941,12 +933,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Cluster", NULL);
 static_button_menu (table, button, 9, 10, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_cluster", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_CLUSTER);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_cluster_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_cluster_copy, window);
@@ -958,7 +950,7 @@ static_item_insert (menu, "Animate", "grey", gamgi_gtk_cluster_animate, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_cluster_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -969,12 +961,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Molecule", NULL);
 static_button_menu (table, button, 8, 9, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_molecule", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_MOLECULE);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_molecule_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_molecule_copy, window);
@@ -986,7 +978,7 @@ static_item_insert (menu, "Animate", "grey", gamgi_gtk_molecule_animate, window)
 static_item_insert (menu, "Remove", "red", gamgi_gtk_molecule_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -997,12 +989,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Group", NULL);
 static_button_menu (table, button, 7, 8, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_group", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_GROUP);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_group_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_group_copy, window);
@@ -1013,7 +1005,7 @@ static_item_insert (menu, "Measure", NULL, gamgi_gtk_group_measure, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_group_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -1024,12 +1016,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Plane", NULL);
 static_button_menu (table, button, 6, 7, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_plane", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_PLANE);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_plane_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_plane_copy, window);
@@ -1040,7 +1032,7 @@ static_item_insert (menu, "Measure", NULL, gamgi_gtk_plane_measure, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_plane_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -1051,12 +1043,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Direction", NULL);
 static_button_menu (table, button, 5, 6, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_direction", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_DIRECTION);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_direction_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_direction_copy, window);
@@ -1067,7 +1059,7 @@ static_item_insert (menu, "Measure", NULL, gamgi_gtk_direction_measure, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_direction_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -1078,12 +1070,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Atom", NULL);
 static_button_menu (table, button, 4, 5, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_atom", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_ATOM);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_atom_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_atom_copy, window);
@@ -1094,7 +1086,7 @@ static_item_insert (menu, "Measure", NULL, gamgi_gtk_atom_measure, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_atom_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", NULL, gamgi_gtk_atom_config, window);
@@ -1105,12 +1097,12 @@ static_item_insert (menu, "Config", NULL, gamgi_gtk_atom_config, window);
 
 button = gamgi_gtk_dialog_button_create ("Bond", NULL);
 static_button_menu (table, button, 3, 4, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_bond", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_BOND);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_bond_create, window);
 static_item_insert (menu, "Select", NULL, gamgi_gtk_bond_select, window);
@@ -1119,7 +1111,7 @@ static_item_insert (menu, "Modify", NULL, gamgi_gtk_bond_modify, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_bond_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", NULL, gamgi_gtk_bond_config, window);
@@ -1130,12 +1122,12 @@ static_item_insert (menu, "Config", NULL, gamgi_gtk_bond_config, window);
 
 button = gamgi_gtk_dialog_button_create ("Orbital", NULL);
 static_button_menu (table, button, 2, 3, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_orbital", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_ORBITAL);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", "grey", gamgi_gtk_orbital_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_orbital_copy, window);
@@ -1145,7 +1137,7 @@ static_item_insert (menu, "Modify", "grey", gamgi_gtk_orbital_modify, window);
 static_item_insert (menu, "Remove", "grey", gamgi_gtk_orbital_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", "grey", NULL, window);
@@ -1156,12 +1148,12 @@ static_item_insert (menu, "Config", "grey", NULL, window);
 
 button = gamgi_gtk_dialog_button_create ("Text", NULL);
 static_button_menu (table, button, 1, 2, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_text", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_TEXT);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_text_create, window);
 static_item_insert (menu, "Copy", NULL, gamgi_gtk_text_copy, window);
@@ -1171,7 +1163,7 @@ static_item_insert (menu, "Modify", NULL, gamgi_gtk_text_modify, window);
 static_item_insert (menu, "Remove", "red", gamgi_gtk_text_remove, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", NULL, gamgi_gtk_text_config, window);
@@ -1182,29 +1174,24 @@ static_item_insert (menu, "Config", NULL, gamgi_gtk_text_config, window);
 
 button = gamgi_gtk_dialog_button_create ("Help", "red");
 static_button_menu (table, button, 0, 1, 1, 2);
+g_signal_connect (button, "event", G_CALLBACK (static_menu), window);
+g_object_set_data (G_OBJECT (window->window), "button_help", button);
+
 menu = gtk_menu_new ();
-g_object_set_data (G_OBJECT (menu), "button", button);
 g_object_set_data (G_OBJECT (menu), "select", (void *) FALSE);
-g_object_set_data (G_OBJECT (menu), "window", (void *) window);
-g_signal_connect_swapped (GTK_OBJECT(button), "event",
-G_CALLBACK (static_menu), GTK_OBJECT(menu));
+g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Current", NULL, gamgi_gtk_help_current, window);
 static_item_insert (menu, "Topic", NULL, gamgi_gtk_help_topic, window);
 static_item_insert (menu, "Search", NULL, gamgi_gtk_help_search, window);
 static_item_insert (menu, "Tutorial", NULL, gamgi_gtk_help_tutorial, window);
-
-/* GTK2
-item = static_item_insert (menu, "Test", NULL, NULL, window);
-submenu = gtk_menu_new ();
-gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
-static_item_insert (submenu, "Progress", NULL, gamgi_gtk_statusbar_mode, window);
+/*
+static_item_insert (menu, "Progress", NULL, gamgi_gtk_statusbar_mode, window);
 */
-
 static_item_insert (menu, "Start", "red", gamgi_gtk_help_start, window);
 
 separator = gtk_menu_item_new ();
-gtk_menu_append (GTK_MENU (menu), separator);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
 gtk_widget_show (separator);
 
 static_item_insert (menu, "Config", NULL, gamgi_gtk_help_config, window);
@@ -1267,21 +1254,9 @@ window->context_time = gtk_statusbar_get_context_id (GTK_STATUSBAR
 gtk_statusbar_set_has_resize_grip  (GTK_STATUSBAR (window->statusbar_time), FALSE);
 gtk_widget_show (window->statusbar_time);
 
-adjustment = (GtkAdjustment *) gtk_adjustment_new (0, 1, 150, 0, 0, 0);
-window->progress_bar = gtk_progress_bar_new_with_adjustment (adjustment);
+window->progress_bar = gtk_progress_bar_new ();
 gtk_widget_set_size_request (window->progress_bar, 80, -1);
-gtk_box_pack_end (GTK_BOX (hbox), window->progress_bar, FALSE, FALSE, 0);
-
-/****************************
- *         start time       *
- *                          *
- * set layer as current     *
- * layer and current object *
- ****************************/
-
-gamgi_gtk_statusbar_time_timeout (NULL);
-gamgi_gtk_object_layer_local (layer, window);
-gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer, window);
+gtk_box_pack_end (GTK_BOX (hbox), window->progress_bar, FALSE, FALSE, 2);
 
 /*********************************
  * command area: entry get focus *
@@ -1317,9 +1292,9 @@ GAMGI_GTK_RULER_MAX, 0, 10000);
 gtk_widget_set_sensitive (window->ruler, FALSE);
 gtk_widget_show (window->ruler);
 
-g_signal_connect (GTK_OBJECT (event_box), "button_press_event",
+g_signal_connect (event_box, "button_press_event",
 G_CALLBACK (static_ruler_press), window);
-g_signal_connect (GTK_OBJECT (event_box), "motion-notify-event",
+g_signal_connect (event_box, "motion-notify-event",
 G_CALLBACK (static_ruler_motion), window);
 
 static_ruler_start (window);
@@ -1347,9 +1322,16 @@ g_object_set_data (G_OBJECT (window->window), "button_scale", button);
 static_button_tool (hbox, "Undo", gamgi_gtk_history_undo, window);
 static_button_tool (hbox, "Save", gamgi_gtk_history_save, window);
 
-if (gamgi->console != 0)
-  static_button_tool (hbox, "Console", static_console, window);
-static_button_tool (hbox, "Shell", static_shell, window);
+/****************************
+ *         start time       *
+ *                          *
+ * set layer as current     *
+ * layer and current object *
+ ****************************/
+
+gamgi_gtk_statusbar_time_timeout (NULL);
+gamgi_gtk_object_layer_local (layer, window);
+gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer, window);
 
 /********************************************************************
  * show and raise new window to the top, hide main,tool,status bars *
@@ -1395,11 +1377,13 @@ void gamgi_gtk_window_create_progress (gamgi_window *window)
 
 if (window->demo_flag != 0)
   {
+/* GTK 2
   gtk_progress_set_activity_mode (GTK_PROGRESS (window->progress_bar), FALSE);
   gtk_widget_hide (window->progress_bar);
   g_source_remove (window->timer_progress);
   window->timer_progress = 0;
   window->demo_flag = 0;
+*/
   }
 }
 
@@ -1417,7 +1401,7 @@ sprintf (string, "%s %d", window->object.name, window->object.number);
 gtk_window_set_title (GTK_WINDOW (window->window), string);
 
 window->action = FALSE;
-window->selection = FALSE;
+window->class = FALSE;
 if (window->axes == TRUE) static_axes (NULL, window);
 static_ruler_off (window);
 }
