@@ -10,6 +10,25 @@
  */
 
 /**********************
+ * external functions *
+ ********************** 
+
+static void static_clean (gamgi_window *window);
+
+static void static_reset (gamgi_window *window);
+
+static void static_global (GtkWidget *widget, void *data);
+
+static void static_apply (gamgi_window *window_mouse,
+gamgi_window *window_dialog);
+
+static void static_ok (GtkWidget *widget, void *data);
+
+static void static_init (gamgi_window *window);
+
+static void static_press (gamgi_object *object, void *data);
+
+ **********************
  * external functions *
  **********************/
 
@@ -24,7 +43,7 @@ void gamgi_gtk_window_remove_ok (GtkWidget *widget, void *data);
 void gamgi_gtk_window_remove_confirm (GtkWidget *widget, void *data);
 
 void gamgi_gtk_window_remove_press (gamgi_window *window_mouse, 
-int x, int y, gamgi_window *window_dialog);
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog);
 
 void gamgi_gtk_window_remove (GtkWidget *widget, void *data);
 
