@@ -77,11 +77,12 @@ GAMGI_IO_HERSHEY_GOTHIC_ENGLISH, GAMGI_IO_HERSHEY_GOTHIC_GERMAN,
 GAMGI_IO_HERSHEY_GOTHIC_ITALIAN, GAMGI_IO_HERSHEY_SYMBOL_SANS,
 GAMGI_IO_HERSHEY_SYMBOL_SERIF, GAMGI_IO_HERSHEY_SYMBOL_SERIF_BOLD,
 
-GAMGI_IO_VERA_SANS, GAMGI_IO_VERA_SANS_BOLD,
-GAMGI_IO_VERA_SANS_ITALIC, GAMGI_IO_VERA_SANS_BOLD_ITALIC,
-GAMGI_IO_VERA_SERIF, GAMGI_IO_VERA_SERIF_BOLD,
-GAMGI_IO_VERA_MONO, GAMGI_IO_VERA_MONO_BOLD,
-GAMGI_IO_VERA_MONO_ITALIC, GAMGI_IO_VERA_MONO_BOLD_ITALIC };
+GAMGI_IO_DEJAVU_SANS, GAMGI_IO_DEJAVU_SANS_BOLD,
+GAMGI_IO_DEJAVU_SANS_ITALIC, GAMGI_IO_DEJAVU_SANS_BOLD_ITALIC,
+GAMGI_IO_DEJAVU_SERIF, GAMGI_IO_DEJAVU_SERIF_BOLD,
+GAMGI_IO_DEJAVU_SERIF_ITALIC, GAMGI_IO_DEJAVU_SERIF_BOLD_ITALIC,
+GAMGI_IO_DEJAVU_MONO, GAMGI_IO_DEJAVU_MONO_BOLD,
+GAMGI_IO_DEJAVU_MONO_ITALIC, GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC };
 
 /************* macros ************
  *********************************/
@@ -100,8 +101,8 @@ GAMGI_IO_VERA_MONO_ITALIC, GAMGI_IO_VERA_MONO_BOLD_ITALIC };
  * the Gamgi->About GUI dialog *
  *******************************/
 
-#define GAMGI_IO_DATE "7th January 2009"
-#define GAMGI_IO_VERSION "0.13.10"
+#define GAMGI_IO_DATE "20th January 2010"
+#define GAMGI_IO_VERSION "0.14.5"
 #define GAMGI_IO_AUTHORS "Carlos Pereira"
 #define GAMGI_IO_LICENSE "GPL"
 #define GAMGI_IO_WEBSITE "http://www.gamgi.org/"
@@ -215,32 +216,34 @@ GAMGI_IO_VERA_MONO_ITALIC, GAMGI_IO_VERA_MONO_BOLD_ITALIC };
  **********************************************************/
 
 #define GAMGI_IO_FONTS_WIRED 14
-#define GAMGI_IO_FONTS_SOLID 10
-#define GAMGI_IO_FONTS_TOTAL 20
+#define GAMGI_IO_FONTS_SOLID 12
+#define GAMGI_IO_FONTS_TOTAL 22
 
 /*****************************************
  * text defaults: wired font, solid font *
  *****************************************/
 
 #define GAMGI_IO_TEXT_WIRED GAMGI_IO_SUN_ROMAN
-#define GAMGI_IO_TEXT_SOLID GAMGI_IO_VERA_SANS
+#define GAMGI_IO_TEXT_SOLID GAMGI_IO_DEJAVU_SANS
 
 /**********************************************
  * Truetype fonts: default path and filenames *
  **********************************************/
 
-#define GAMGI_IO_PATH_TRUETYPE "/usr/X11/lib/X11/fonts/truetype/"
+#define GAMGI_IO_PATH_TRUETYPE "/usr/share/fonts/truetype/ttf-dejavu/"
 
-#define GAMGI_IO_FILENAME_VERA_SANS "Vera.ttf"
-#define GAMGI_IO_FILENAME_VERA_SANS_BOLD "VeraBd.ttf"
-#define GAMGI_IO_FILENAME_VERA_SANS_ITALIC "VeraIt.ttf"
-#define GAMGI_IO_FILENAME_VERA_SANS_BOLD_ITALIC "VeraBI.ttf"
-#define GAMGI_IO_FILENAME_VERA_SERIF "VeraSe.ttf"
-#define GAMGI_IO_FILENAME_VERA_SERIF_BOLD "VeraSeBd.ttf"
-#define GAMGI_IO_FILENAME_VERA_MONO "VeraMono.ttf"
-#define GAMGI_IO_FILENAME_VERA_MONO_BOLD "VeraMoBd.ttf"
-#define GAMGI_IO_FILENAME_VERA_MONO_ITALIC "VeraMoIt.ttf"
-#define GAMGI_IO_FILENAME_VERA_MONO_BOLD_ITALIC "VeraMoBI.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_SANS "DejaVuSans.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_SANS_BOLD "DejaVuSans-Bold.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_SANS_ITALIC "DejaVuSans-Oblique.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_SANS_BOLD_ITALIC "DejaVuSans-BoldOblique.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_SERIF "DejaVuSerif.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_SERIF_BOLD "DejaVuSerif-Bold.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_SERIF_ITALIC "DejaVuSerif-Italic.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_SERIF_BOLD_ITALIC "DejaVuSerif-BoldItalic.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_MONO "DejaVuSansMono.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_MONO_BOLD "DejaVuSansMono-Bold.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_MONO_ITALIC "DejaVuSansMono-Oblique.ttf"
+#define GAMGI_IO_FILENAME_DEJAVU_MONO_BOLD_ITALIC "DejaVuSansMono-BoldOblique.ttf"
 
 /*******************************
  * Size of the font arrays     *
