@@ -30,6 +30,68 @@
 
 #include <fcntl.h>
 
+static gamgi_bool static_tokens (char *string, char *tokens,
+int n_tokens, gamgi_bool end)
+{
+gamgi_bool start;
+char *substring;
+int i, length = 0;
+
+for (i = 0; i < n_tokens; i++)
+  {
+  if (tokens[0] == '\0') { start = TRUE; tokens++; }
+  else start = FALSE;
+
+  if ((substring = strstr (string, tokens)) == NULL) return FALSE;
+  if (start == FALSE && substring != string) return FALSE;
+
+  length = strlen (tokens);
+  string = substring;
+  tokens += length;
+  }
+
+if (end == FALSE && strstr (string + strlen (string) - length,
+tokens - length) == NULL) return FALSE;
+
+return TRUE;
+}
+
+static gamgi_bool static_pattern (char *string, char *pattern)
+{
+gamgi_bool start, end;
+char *tokens = pattern;
+int i, n_tokens;
+
+/********************************************
+ * convert the whole pattern sequence to a  *
+ * list of patterns separated by '\0' chars *
+ ********************************************/
+
+n_tokens = 0;
+for (i = 0; *pattern != '\0'; pattern++)
+  {
+  if (*pattern == '*')
+    {
+    if (*(pattern + 1) == '*') continue;
+    tokens[i++] = '\0';
+    n_tokens++;
+    }
+  else tokens[i++] = *pattern;
+  }
+tokens[i] = '\0';
+
+if (tokens[0] == '\0') start = TRUE;
+else start = FALSE;
+
+if (tokens[i - 1] == '\0') end = TRUE;
+else end = FALSE;
+
+if (start == TRUE && end == TRUE) n_tokens--;
+if (start == FALSE && end == FALSE) n_tokens++;
+
+return static_tokens (string, tokens, n_tokens, end);
+}
+
 static gamgi_bool static_line (int socket,
 char *buffer, char *line, int *available)
 {
@@ -135,6 +197,26 @@ if (sscanf (line+1, " %d, %d ", &n1, &n2) != 2)
 return TRUE;
 }
 
+gamgi_bool gamgi_io_file_patterns (char *file, const char *filters)
+{
+char patterns[GAMGI_GTK_FILE_PATTERNS + 1];
+char *pattern;
+
+/******************************************
+ * divide sequence in individual patterns *
+ ******************************************/
+ 
+strcpy (patterns, filters);
+pattern = strtok (patterns, " ,");
+do
+  {
+  if (static_pattern (file, pattern) == TRUE) return TRUE;
+  }
+  while ((pattern = strtok (NULL, " ,")) != NULL);
+   
+return FALSE;
+}
+
 char *gamgi_io_file_shortname (const char *fullname)
 {
 char *shortname;
@@ -270,6 +352,7 @@ char filename[GAMGI_ENGINE_LINE];
 char hostname[GAMGI_ENGINE_LINE];
 char *body;
 gamgi_bool valid;
+int out;
 
 /*****************************
  * get hostname and filename *
@@ -296,7 +379,7 @@ if (fd < 0) return gamgi_io_error_open (shortname, window);
 sprintf (buffer, "GET %s HTTP/1.1\r\n" "Host: %s\r\n"
 "Pragma: no-cache\r\n" "Connection: close\r\n\r\n",
 filename, hostname);
-write (fd, buffer, strlen (buffer));
+out = write (fd, buffer, strlen (buffer));
 
 /**********************
  * handle HTTP header *
@@ -565,7 +648,7 @@ char string[GAMGI_ENGINE_LINE];
  *************/
 
 components = 3;
-pixels = gamgi_mesa_area_grab (0, 0, width, height);
+pixels = gamgi_mesa_area_read (0, 0, width, height);
 
 /***********************************************************
  * Write header, adapted from: 1) the header produced      *
@@ -635,7 +718,7 @@ int i, components, maximum, offset;
  ***************************************************************/
 
 components = 3;
-pixels = gamgi_mesa_area_grab (0, 0, width, height);
+pixels = gamgi_mesa_area_read (0, 0, width, height);
 maximum = GAMGI_IO_PPM_MAX;
 
 /****************
@@ -683,6 +766,7 @@ FILE *fp, int width, int height, gamgi_bool *error)
 {
 char auxname[2 * GAMGI_ENGINE_TOKEN];
 char command[2 * GAMGI_ENGINE_LINE];
+int out;
 
 /**********************************
  * 1) create fullname ppm file    *
@@ -699,7 +783,7 @@ sprintf (auxname, "gamgi%d", getpid ());
 
 sprintf (command, "(%s %s >%s; mv -f %s %s) &",
 GAMGI_IO_PNMTOPNG, fullname, auxname, auxname, fullname);
-system (command);
+out = system (command);
 
 return TRUE;
 }
@@ -709,6 +793,7 @@ FILE *fp, int width, int height, gamgi_bool *error)
 {
 char auxname[2 * GAMGI_ENGINE_TOKEN];
 char command[2 * GAMGI_ENGINE_LINE];
+int out;
 
 /**********************************
  * 1) create fullname ppm file    *
@@ -725,7 +810,7 @@ sprintf (auxname, "gamgi%d", getpid ());
 
 sprintf (command, "(%s %s >%s; mv -f %s %s) &",
 GAMGI_IO_PNMTOJPEG, fullname, auxname, auxname, fullname);
-system (command);
+out = system (command);
 
 return TRUE;
 }
@@ -735,6 +820,7 @@ FILE *fp, int width, int height, gamgi_bool *error)
 {
 char auxname[2 * GAMGI_ENGINE_TOKEN];
 char command[2 * GAMGI_ENGINE_LINE];
+int out;
 
 /**********************************
  * 1) create fullname ppm file    *
@@ -751,7 +837,7 @@ sprintf (auxname, "gamgi%d", getpid ());
 
 sprintf (command, "(%s -color %s >%s; mv -f %s %s) &",
 GAMGI_IO_PNMTOTIFF, fullname, auxname, auxname, fullname);
-system (command);
+out = system (command);
 
 return TRUE;
 }
