@@ -441,6 +441,98 @@ gamgi_math_position_translation (plane->object.object, vector);
 gamgi_math_vector_sub (plane->origin, vector, relative);
 }
 
+void gamgi_math_position_group_rotation_set (gamgi_group *group, double *euler)
+{
+double matrix[9], inverse[9], relative[9], rotate[9];
+double quaternion[4];
+double center[3];
+
+/******************************************************************
+ * backward and forward rotations are applied around an arbitrary *
+ * point center, as the rotation itself is independent of the     *
+ * rotation center and the origin is then used in the translation *
+ * applied next to properly positionate the direction             *
+ ******************************************************************/
+
+gamgi_math_vector_zero (center);
+
+/*********************************************
+ * rotate group backward, to properly reset  *
+ * rotation, updating also origin and center *
+ *********************************************/
+
+gamgi_math_quaternion_to_matrix (group->quaternion, matrix);
+gamgi_math_matrix_inverse (matrix, inverse);
+gamgi_math_quaternion_from_matrix (inverse, quaternion);
+gamgi_mesa_rotate_group (group, quaternion, inverse, center);
+
+/***********************************************************
+ *    rotate group foward, after rotating parent,          *
+ *    to properly update group origin and center           *
+ *                                                         *
+ * The group euler angles show only the difference         *
+ * between the group and cell rotation, while the          *
+ * group quaternion stores the whole group rotation.       *
+ *                                                         *
+ * first apply the cell rotation, then the group rotation. *
+ ***********************************************************/
+
+gamgi_math_position_rotation (group->object.object, matrix);
+gamgi_math_euler_to_matrix (euler, relative);
+gamgi_math_matrix_matrix (relative, matrix, rotate);
+gamgi_math_quaternion_from_matrix (rotate, quaternion);
+gamgi_mesa_rotate_group (group, quaternion, rotate, center);
+}
+
+void gamgi_math_position_group_rotation_get (gamgi_group *group, double *euler)
+{
+double matrix[9], inverse[9], relative[9], rotate[9];
+
+if (group->autonomy == GAMGI_GTK_NONE)
+  { gamgi_math_vector_zero (euler); return; }
+
+/***********************************************************
+ * The group euler angles show only the rotation           *
+ * difference between the group and the parent, while      *
+ * the group quaternion stores the whole group rotation.   *
+ *                                                         *
+ * first apply the cell rotation, then the group rotation. *
+ ***********************************************************/
+
+gamgi_math_position_rotation (group->object.object, matrix);
+
+gamgi_math_matrix_inverse (matrix, inverse);
+gamgi_math_quaternion_to_matrix (group->quaternion, rotate);
+gamgi_math_matrix_matrix (rotate, inverse, relative);
+gamgi_math_euler_from_matrix (relative, euler);
+}
+
+void gamgi_math_position_group_translation_set (gamgi_group *group, double *relative)
+{
+double vector[3], absolute[3], translate[3];
+
+/******************************************************************
+ * correct the group origin change due to the previous rotation:  *
+ * as this is applied around the group center, its origin changes *
+ ******************************************************************/
+
+gamgi_math_position_translation (group->object.object, vector);
+gamgi_math_vector_add (vector, relative, absolute);
+gamgi_math_vector_sub (absolute, group->origin, translate);
+gamgi_mesa_translate_group (group, translate);
+}
+
+void gamgi_math_position_group_translation_get (gamgi_group *group, double *relative)
+{
+double vector[3];
+
+if (group->autonomy == GAMGI_GTK_NONE)
+  { gamgi_math_vector_zero (relative); return; }
+
+gamgi_math_position_translation (group->object.object, vector);
+gamgi_math_vector_sub (group->origin, vector, relative);
+}
+
 void gamgi_math_position_cell_rotation_set (gamgi_cell *cell, double *euler)
 {
 double matrix[9], inverse[9], rotate[9];
@@ -513,8 +605,8 @@ gamgi_math_vector_sub (origin, cell->origin, translate);
 gamgi_math_cell_offset (cell, old);
 gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
 gamgi_math_matrix_vector (rotate, old, new);
-
 gamgi_math_vector_sub (translate, new, translate);
+
 gamgi_mesa_translate_cell (cell, translate);
 }
 
