@@ -182,46 +182,55 @@ void gamgi_mesa_text_data_solid (gamgi_enum font, char *filename)
 {
 switch (font)
   {
-  case GAMGI_IO_VERA_SANS:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_SANS);
+  case GAMGI_IO_DEJAVU_SANS:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_SANS);
   break;
 
-  case GAMGI_IO_VERA_SANS_BOLD:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_SANS_BOLD);
+  case GAMGI_IO_DEJAVU_SANS_BOLD:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_SANS_BOLD);
   break;
 
-  case GAMGI_IO_VERA_SANS_ITALIC:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_SANS_ITALIC);
+  case GAMGI_IO_DEJAVU_SANS_ITALIC:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_SANS_ITALIC);
   break;
 
-  case GAMGI_IO_VERA_SANS_BOLD_ITALIC:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_SANS_BOLD_ITALIC);
+  case GAMGI_IO_DEJAVU_SANS_BOLD_ITALIC:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_SANS_BOLD_ITALIC);
   break;
 
-  case GAMGI_IO_VERA_SERIF:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_SERIF);
+  case GAMGI_IO_DEJAVU_SERIF:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_SERIF);
   break;
 
-  case GAMGI_IO_VERA_SERIF_BOLD:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_SERIF_BOLD);
+  case GAMGI_IO_DEJAVU_SERIF_BOLD:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_SERIF_BOLD);
   break;
 
-  case GAMGI_IO_VERA_MONO:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_MONO);
+  case GAMGI_IO_DEJAVU_SERIF_ITALIC:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_SERIF_ITALIC);
   break;
 
-  case GAMGI_IO_VERA_MONO_BOLD:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_MONO_BOLD);
+  case GAMGI_IO_DEJAVU_SERIF_BOLD_ITALIC:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_SERIF_BOLD_ITALIC);
   break;
 
-  case GAMGI_IO_VERA_MONO_ITALIC:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_MONO_ITALIC);
+  case GAMGI_IO_DEJAVU_MONO:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_MONO);
   break;
 
-  case GAMGI_IO_VERA_MONO_BOLD_ITALIC:
-  strcpy (filename, GAMGI_IO_FILENAME_VERA_MONO_BOLD_ITALIC);
+  case GAMGI_IO_DEJAVU_MONO_BOLD:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_MONO_BOLD);
+  break;
+
+  case GAMGI_IO_DEJAVU_MONO_ITALIC:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_MONO_ITALIC);
+  break;
+
+  case GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC:
+  strcpy (filename, GAMGI_IO_FILENAME_DEJAVU_MONO_BOLD_ITALIC);
   break;
   }
+
 }
 
 void gamgi_mesa_text_font_create (gamgi_enum font, int **glyphs)
@@ -1057,7 +1066,7 @@ FT_Library *freetype, FT_Face *face)
 {
 gamgi_extruded *extruded;
 char fullname[GAMGI_IO_FULLNAME];
-char filename[GAMGI_ENGINE_TOKEN];
+char filename[GAMGI_ENGINE_STRING];
 
 /*********************
  * get font filename *
