@@ -38,6 +38,7 @@
 #include "gamgi_math_position.h"
 #include "gamgi_math_cell.h"
 #include "gamgi_math_node.h"
+#include "gamgi_chem_atom.h"
 #include "gamgi_phys_cell.h"
 #include "gamgi_phys_plane.h"
 #include "gamgi_phys_direction.h"
@@ -78,12 +79,57 @@ do
 while (gamgi_phys_direction_higher (t_old, t_new) == TRUE);
 }
 
+static void static_extremities (int n_neighbours, gamgi_atom **neighbours,
+int *n_min, int *n_max)
+{
+gamgi_atom *atom, *atom_before;
+double x, y, z;
+double min, max;
+int i, d;
+
+/********************************************************
+ * get main axis: the axis where coodinates change more *
+ ********************************************************/
+
+x = 0; y = 0; z = 0;
+for (i = 1; i < n_neighbours; i++)
+  {
+  atom_before = neighbours[i - 1];
+  atom = neighbours[i];
+
+  x += fabs (atom->position[0] - atom_before->position[0]);
+  y += fabs (atom->position[1] - atom_before->position[1]);
+  z += fabs (atom->position[2] - atom_before->position[2]);
+  }
+
+max = x; d = 0;
+if (y > max) { max = y; d = 1; }
+if (z > max) { max = z; d = 2; }
+
+/************************************
+ * get minimum and maximum points,  *
+ * the extremities, along main axis *
+ ************************************/
+
+min = DBL_MAX; max = -DBL_MAX;
+for (i = 0; i < n_neighbours; i++)
+  {
+  atom = neighbours[i];
+
+  if (atom->position[d] < min)
+    { min = atom->position[d]; *n_min = i; }
+  if (atom->position[d] > max)
+    { max = atom->position[d]; *n_max = i; }
+  }
+
+}
+
 static void static_segment (gamgi_darray *darray)
 {
 double *points;
 double u[3], v[3];
 double length, length_max;
-int n1, n2, n_points;
+int m, n, n_points;
 int i, j;
 
 /**************
@@ -106,7 +152,7 @@ points = darray->array;
  * the array is eliminated later, after a length check.      *
  *************************************************************/
 
-n1 = -1; n2 = -1;
+m = -1; n = -1;
 length_max = -DBL_MAX;
 for (i = 0; i < n_points - 1; i++)
   {
@@ -115,7 +161,7 @@ for (i = 0; i < n_points - 1; i++)
     gamgi_math_vector_sub (points + 4*i, points + 4*j, u);
     length = gamgi_math_vector_length (u);
 
-    if (length > length_max) { length_max = length; n1 = i; n2 = j; }
+    if (length > length_max) { length_max = length; m = i; n = j; }
     }
   }
 
@@ -123,8 +169,9 @@ for (i = 0; i < n_points - 1; i++)
  * save extreme points *
  ***********************/
 
-gamgi_math_vector_copy (points + 4 * n1, u);
-gamgi_math_vector_copy (points + 4 * n2, v);
+gamgi_math_vector_copy (points + 4 * m, u);
+gamgi_math_vector_copy (points + 4 * n, v);
+
 gamgi_math_vector_copy (u, points);
 gamgi_math_vector_copy (v, points + 3);
 
@@ -254,11 +301,10 @@ for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
 }
 
 static void static_copy (gamgi_direction *direction,
-double *normal, gamgi_dlist *dlist)
+double *normal, gamgi_dlist *atoms)
 {
 gamgi_atom *atom, *atom_new;
-gamgi_bond *bond;
-gamgi_dlist *dlist_a, *dlist_b;
+gamgi_dlist *dlist;
 double r[3], s[3];
 double length;
 
@@ -267,9 +313,9 @@ double length;
  * in parent that are closer than thickness *
  ********************************************/
 
-for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
+for (dlist = atoms; dlist != NULL; dlist = dlist->next)
   {
-  atom = GAMGI_CAST_ATOM dlist_a->data;
+  atom = GAMGI_CAST_ATOM dlist->data;
 
   gamgi_math_vector_sub (atom->position, direction->center, r);
   length = gamgi_math_vector_dot (r, normal);
@@ -288,16 +334,8 @@ for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
  * clean bonds in parent object *
  ********************************/
 
-for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
-  {
-  atom = GAMGI_CAST_ATOM dlist_a->data;
-  for (dlist_b = atom->bond_start; dlist_b != NULL; dlist_b = dlist_b->next)
-    {
-    bond = GAMGI_CAST_BOND dlist_b->data;
-    bond->copy = NULL;
-    }
-  }
-
+for (dlist = atoms; dlist != NULL; dlist = dlist->next)
+  gamgi_chem_atom_clean (GAMGI_CAST_ATOM dlist->data);
 }
 
 static int static_order (int *hkl, gamgi_cell *cell, int step)
@@ -898,36 +936,6 @@ if (length < GAMGI_MATH_TOLERANCE_LENGTH) return FALSE;
 return TRUE;
 }
 
-gamgi_dlist *gamgi_phys_direction_filter (gamgi_dlist *start)
-{
-gamgi_atom *atom;
-gamgi_dlist *dlist;
-gamgi_enum class;
-
-/***************************************************************
- * remove from dlist atoms linked to planes and directions     *
- * to avoid conflicts between tasks applied to similar objects *
- ***************************************************************/
-
-dlist = start;
-start = NULL;
-while (dlist != NULL)
-  {
-  atom = GAMGI_CAST_ATOM dlist->data;
-  class = atom->object.object->class;
-
-  if (class == GAMGI_ENGINE_PLANE || class == GAMGI_ENGINE_DIRECTION)
-    dlist = gamgi_engine_dlist_remove_start (dlist);
-  else
-    {
-    if (start == NULL) start = dlist;
-    dlist = dlist->next;
-    }
-  }
-
-return start;
-}
-
 gamgi_dlist *gamgi_phys_direction_reorder (gamgi_dlist *start,
 gamgi_atom *atom1, gamgi_atom *atom2)
 {
@@ -1044,6 +1052,106 @@ while (dlist != NULL)
   dlist = gamgi_engine_dlist_remove_start (dlist);
 }
 
+void gamgi_phys_direction_polytope (int n_neighbours, gamgi_atom **neighbours,
+gamgi_enum autonomy, float red, float green, float blue, gamgi_object *parent,
+gamgi_atom *central)
+{
+gamgi_direction *direction;
+gamgi_atom *atom;
+double unit[9], rotation[9];
+double zero[3], translation[3];
+int i, min, max;
+
+autonomy = GAMGI_GTK_NONE;
+
+/********************************************************
+ * link direction and set type before handling rotation *
+ ********************************************************/
+
+direction = gamgi_engine_create_direction ();
+gamgi_engine_start_direction (direction);
+gamgi_engine_link_object_object (GAMGI_CAST_OBJECT direction, parent);
+strcpy (direction->object.name, "Direction");
+
+direction->reference = GAMGI_ENGINE_ATOM;
+direction->type = GAMGI_PHYS_LINE;
+direction->autonomy = autonomy;
+direction->thickness = GAMGI_CHEM_DIRECTION_THICKNESS;
+
+direction->red = red;
+direction->green = green;
+direction->blue = blue;
+
+/**********************************************************************
+ * initially the parent object is rotated and translated backward so  *
+ * the direction is built with zero translation and rotation. In the  *
+ * end, the parent object is rotated and translated forward to its    *
+ * initial position, this time already including the direction, which *
+ * will acquire the same origin and rotation as the parent object.    *
+ **********************************************************************/
+
+gamgi_math_vector_zero (zero);
+gamgi_math_matrix_unit (unit);
+
+gamgi_math_position_direction_rotation_set (direction, zero);
+gamgi_math_position_direction_translation_set (direction, zero);
+
+gamgi_math_position_rotation (parent, rotation);
+gamgi_math_position_translation (parent, translation);
+
+gamgi_math_position_object_rotation (parent, unit);
+gamgi_math_position_object_translation (parent, zero);
+
+/***************************************************
+ * this is not necessary but prevents a O3 warning *
+ ***************************************************/
+
+min = -1; max = -1;
+
+/************************************
+ * get atoms defining segment with  *
+ * maximum length (the extremities) *
+ ************************************/
+
+static_extremities (n_neighbours, neighbours, &min, &max);
+
+direction->n_points = 2;
+direction->points = (double *) malloc (3 * direction->n_points * sizeof (double));
+
+atom = neighbours[min];
+gamgi_math_vector_copy (atom->position, direction->points);
+atom = neighbours[max];
+gamgi_math_vector_copy (atom->position, direction->points + 3);
+
+gamgi_math_polygon_lines (direction->n_points, &direction->loops, 
+&direction->n_loops);
+static_center (direction);
+
+/************************************************
+ * copy all neighbours from parent to direction *
+ ************************************************/
+
+if (direction->autonomy == GAMGI_GTK_ALL)
+  {
+  atom = gamgi_engine_copy_atom (central);
+  gamgi_engine_link_atom_direction (atom, direction);
+
+  for (i = 0; i < n_neighbours; i++)
+    {
+    atom = gamgi_engine_copy_atom (neighbours[i]);
+    gamgi_engine_link_atom_direction (atom, direction);
+    }
+  }
+
+/*******************************************
+ * rotate the parent object, including     *
+ * the direction, to its original position *
+ *******************************************/
+
+gamgi_math_position_object_rotation (direction->object.object, rotation);
+gamgi_math_position_object_translation (direction->object.object, translation);
+}
+
 void gamgi_phys_direction_range (gamgi_direction *direction,
 gamgi_cell *cell, int *hkl1, int start1, int end1, int *hkl2,
 int start2, int end2)
@@ -1182,7 +1290,8 @@ if (direction->autonomy != GAMGI_GTK_NONE)
   gamgi_math_vector_normal (normal);
 
   dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
-  dlist = gamgi_phys_direction_filter (dlist);
+  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
+  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
   if (direction->autonomy == GAMGI_GTK_PARTIAL)
     static_link (direction, normal, dlist);
   if (direction->autonomy == GAMGI_GTK_ALL)
