@@ -13,6 +13,7 @@
 #include "gamgi_gtk.h"
 #include "gamgi_mesa.h"
 #include "gamgi_math.h"
+#include "gamgi_chem.h"
 #include "gamgi_phys.h"
 #include "gamgi_global.h"
 
@@ -35,6 +36,7 @@
 #include "gamgi_math_cell.h"
 #include "gamgi_math_node.h"
 #include "gamgi_math_position.h"
+#include "gamgi_chem_atom.h"
 #include "gamgi_phys_cell.h"
 #include "gamgi_phys_plane.h"
 #include "gamgi_phys_direction.h"
@@ -822,7 +824,7 @@ for (n = 0; n < plane->n_points; n++)
 gamgi_math_vector_scale (plane->center, plane->center, 1.0 / plane->n_points);
 }
 
-static gamgi_darray *static_polygon (gamgi_plane *plane,
+static gamgi_darray *static_polygon_dlist (gamgi_plane *plane,
 double *position, double *normal, gamgi_dlist *dlist)
 {
 gamgi_atom *atom;
@@ -867,6 +869,38 @@ while (dlist != NULL)
 return darray;
 }
 
+static gamgi_darray *static_polygon_array (gamgi_plane *plane,
+int n_neighbours, gamgi_atom **neighbours)
+{
+gamgi_atom *atom;
+gamgi_darray *darray;
+int i;
+
+/**************************************************
+ * store 4-coordinate points: the 4th coordinate  *
+ * will be used later to order the polygon points *
+ **************************************************/
+
+darray = gamgi_engine_darray_create (GAMGI_MATH_PLANE_SIZE,
+GAMGI_MATH_PLANE_STEP, 4);
+
+/*******************************************
+ * build plane polygon with all neighbours *
+ *******************************************/
+
+for (i = 0; i < n_neighbours; i++)
+  {
+  /*****************************
+   * add atom point to polygon *
+   *****************************/
+
+  atom = neighbours[i];
+  gamgi_engine_darray_push (darray, atom->position);
+  }
+
+return darray;
+}
+
 static void static_link (gamgi_plane *plane,
 double *normal, gamgi_dlist *dlist)
 {
@@ -897,11 +931,10 @@ for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
 }
 
 static void static_copy (gamgi_plane *plane,
-double *normal, gamgi_dlist *dlist)
+double *normal, gamgi_dlist *atoms)
 {
 gamgi_atom *atom, *atom_new;
-gamgi_bond *bond;
-gamgi_dlist *dlist_a, *dlist_b;
+gamgi_dlist *dlist;
 double r[3];
 double length;
 
@@ -910,9 +943,9 @@ double length;
  * in parent that are closer than thickness *
  ********************************************/
 
-for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
+for (dlist = atoms; dlist != NULL; dlist = dlist->next)
   {
-  atom = GAMGI_CAST_ATOM dlist_a->data;
+  atom = GAMGI_CAST_ATOM dlist->data;
 
   gamgi_math_vector_sub (atom->position, plane->center, r);
   length = gamgi_math_vector_dot (r, normal);
@@ -928,15 +961,8 @@ for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
  * clean bonds in parent object *
  ********************************/
 
-for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
-  {
-  atom = GAMGI_CAST_ATOM dlist_a->data;
-  for (dlist_b = atom->bond_start; dlist_b != NULL; dlist_b = dlist_b->next)
-    {
-    bond = GAMGI_CAST_BOND dlist_b->data;
-    bond->copy = NULL;
-    }
-  }
+for (dlist = atoms; dlist != NULL; dlist = dlist->next)
+  gamgi_chem_atom_clean (GAMGI_CAST_ATOM dlist->data);
     
 }
 
@@ -1344,7 +1370,11 @@ void gamgi_phys_plane_reciprocal (gamgi_cell *cell,
 double reciprocal, double *transformation, double *orientation)
 {
 int *index;
-int offset[3];
+int offset[3] = {0};
+
+/*****************************************************
+ * initialize offset, to avoid a compilation warning *
+ *****************************************************/
 
 index = static_index_nodes (cell);
 static_index_origin (cell, offset);
@@ -1372,15 +1402,17 @@ gamgi_math_matrix_vector (rotate, plane->points, point);
 gamgi_math_vector_add (point, cell->origin, point);
 }
 
-void gamgi_phys_plane_normal (gamgi_plane *plane, double *normal)
+gamgi_bool gamgi_phys_plane_normal (gamgi_plane *plane, double *normal)
 {
 double rotate[9];
 double vector[3];
 
-static_normal (plane, vector);
+if (static_normal (plane, vector) == FALSE) return FALSE;
 
 gamgi_math_quaternion_to_matrix (plane->quaternion, rotate);
 gamgi_math_matrix_vector (rotate, vector, normal);
+
+return TRUE;
 }
 
 void gamgi_phys_plane_default (double *p1, double *p2, 
@@ -1620,38 +1652,6 @@ if (length < GAMGI_MATH_TOLERANCE_LENGTH) return FALSE;
 return TRUE;
 }
 
-gamgi_dlist *gamgi_phys_plane_filter (gamgi_dlist *start)
-{
-gamgi_atom *atom;
-gamgi_dlist *dlist;
-gamgi_enum class;
-
-/************************************************************
- * Remove from dlist atoms linked to planes and directions. *
- * This is used to avoid conflicts between tasks applied to *
- * similar objects or to find atoms in the parent for plane *
- * or direction that are not in the plane or direction.     *
- ************************************************************/
-
-dlist = start;
-start = NULL;
-while (dlist != NULL)
-  {
-  atom = GAMGI_CAST_ATOM dlist->data;
-  class = atom->object.object->class;
-
-  if (class == GAMGI_ENGINE_PLANE || class == GAMGI_ENGINE_DIRECTION)
-    dlist = gamgi_engine_dlist_remove_start (dlist);
-  else
-    {
-    if (start == NULL) start = dlist;
-    dlist = dlist->next;
-    }
-  }
-
-return start;
-}
-
 gamgi_dlist *gamgi_phys_plane_reorder (gamgi_dlist *start,
 gamgi_atom *atom1, gamgi_atom *atom2, gamgi_atom *atom3)
 {
@@ -1717,7 +1717,7 @@ gamgi_math_position_object_translation (plane->object.object, zero);
  *  get normal vector: we tested before if     *
  *  the three atoms can define a real plane    *
  *                                             *
- * use atom1->position as a point in the plane *
+ *    use atom1 for a point in the plane       *
  *                                             *
  *    get darray with all polygon points       *
  *                                             *
@@ -1728,7 +1728,7 @@ gamgi_math_position_object_translation (plane->object.object, zero);
 gamgi_math_polygon_normal (atom1->position,
 atom2->position, atom3->position, normal);
 
-darray = static_polygon (plane, atom1->position, normal, dlist);
+darray = static_polygon_dlist (plane, atom1->position, normal, dlist);
 
 gamgi_math_polygon_orientate (darray, normal);
 gamgi_math_polygon_convex (darray, normal);
@@ -1771,6 +1771,115 @@ while (dlist != NULL)
   dlist = gamgi_engine_dlist_remove_start (dlist);
 }
 
+void gamgi_phys_plane_polytope (int n_neighbours, gamgi_atom **neighbours,
+gamgi_enum autonomy, float red, float green, float blue, gamgi_object *parent,
+gamgi_atom *central)
+{
+gamgi_plane *plane;
+gamgi_atom *atom;
+gamgi_darray *darray;
+double unit[9], rotation[9];
+double zero[3], normal[3], translation[3];
+int i;
+
+autonomy = GAMGI_GTK_NONE;
+
+/********************************************************
+ * link plane and set type before handling rotation *
+ ********************************************************/
+
+plane = gamgi_engine_create_plane ();
+gamgi_engine_start_plane (plane);
+gamgi_engine_link_object_object (GAMGI_CAST_OBJECT plane, parent);
+strcpy (plane->object.name, "Plane");
+
+plane->reference = GAMGI_ENGINE_ATOM;
+plane->type = GAMGI_PHYS_POLYGON;
+plane->autonomy = autonomy;
+plane->thickness = GAMGI_CHEM_PLANE_THICKNESS;
+
+plane->red = red;
+plane->green = green;
+plane->blue = blue;
+
+/**********************************************************************
+ * initially the parent object is rotated and translated backward so  *
+ * the direction is built with zero translation and rotation. In the  *
+ * end, the parent object is rotated and translated forward to its    *
+ * initial position, this time already including the direction, which *
+ * will acquire the same origin and rotation as the parent object.    *
+ **********************************************************************/
+
+gamgi_math_vector_zero (zero);
+gamgi_math_matrix_unit (unit);
+
+gamgi_math_position_plane_rotation_set (plane, zero);
+gamgi_math_position_plane_translation_set (plane, zero);
+
+gamgi_math_position_rotation (parent, rotation);
+gamgi_math_position_translation (parent, translation);
+
+gamgi_math_position_object_rotation (parent, unit);
+gamgi_math_position_object_translation (parent, zero);
+
+/***********************************************
+ *  get normal vector: by construction, the    *
+ *  first three atoms can define a real plane  *
+ *                                             *
+ * use neighbours[0] for a point in the plane  *
+ *                                             *
+ *    get darray with all polygon points       *
+ *                                             *
+ * orient polygon points, remove the redundant *
+ * ones and expand polygon to make it convex   *
+ ***********************************************/
+
+gamgi_math_polygon_normal (neighbours[0]->position,
+neighbours[1]->position, neighbours[2]->position, normal);
+
+darray = static_polygon_array (plane, n_neighbours, neighbours);
+
+gamgi_math_polygon_orientate (darray, normal);
+gamgi_math_polygon_convex (darray, normal);
+
+/***************************
+ * save points array data  *
+ * and remove array object *
+ *                         *
+ *   create loops array    *
+ *                         *
+ *   get polygon center    *
+ ***************************/
+
+gamgi_engine_darray_copy_remove (darray, &plane->points, &plane->n_points);
+gamgi_math_polygon_loops (plane->n_points, &plane->loops, &plane->n_loops);
+static_center (plane);
+
+/********************************************
+ * copy all neighbours from parent to plane *
+ ********************************************/
+
+if (plane->autonomy == GAMGI_GTK_ALL)
+  {
+  atom = gamgi_engine_copy_atom (central);
+  gamgi_engine_link_atom_plane (atom, plane);
+
+  for (i = 0; i < n_neighbours; i++)
+    {
+    atom = gamgi_engine_copy_atom (neighbours[i]);
+    gamgi_engine_link_atom_plane (atom, plane);
+    }
+  }
+
+/***************************************
+ * rotate the parent object, including *
+ * the plane, to its original position *
+ ***************************************/
+
+gamgi_math_position_object_rotation (plane->object.object, rotation);
+gamgi_math_position_object_translation (plane->object.object, translation);
+}
+
 void gamgi_phys_plane_range (gamgi_plane *plane, 
 gamgi_cell *cell, int start, int end)
 {
@@ -1781,7 +1890,8 @@ double vector[3], normal[3];
 if (plane->autonomy != GAMGI_GTK_NONE)
   {
   dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
-  dlist = gamgi_phys_plane_filter (dlist);
+  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
+  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
 
   /**********************************************
    * link atoms to plane: 1) get plane normal,  *
